@@ -1,14 +1,11 @@
 /*
                          NETWIB - NETWOX - NETWAG
                            Installation program
-                   Copyright(c) 2004 Laurent Constantin
+                 Copyright(c) 2004-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwib/ox/ag.
 
   Netwib/ox/ag is free software; you can redistribute it and/or
@@ -23,6 +20,15 @@
 ------------------------------------------------------------------------
 */
 
+/* IMPORTANT :
+   In order to compile this code with Dev-C++, go to:
+     Project
+     Project Options
+     Parameters
+     Linker
+     Add in the text area : -lole32 -luuid
+*/
+
 /*-------------------------------------------------------------*/
 /* This program permits to install netwib, netwox and netwag
    under Windows. */
@@ -37,6 +43,7 @@
 #include <stdio.h>
 #include <conio.h>
 #include <string.h>
+#include <ctype.h>
 #include <windows.h>
 #include <objbase.h>
 #include <shlobj.h>
@@ -173,7 +180,9 @@ typedef enum {
   INST_WINDOWSTYPE_NT4,         /* Windows NT 4 */
   INST_WINDOWSTYPE_2000,        /* Windows 2000 */
   INST_WINDOWSTYPE_XP,          /* Windows XP */
-  INST_WINDOWSTYPE_2003         /* Windows 2003 (or .Net) */
+  INST_WINDOWSTYPE_2003,        /* Windows 2003 */
+  INST_WINDOWSTYPE_2008,        /* Windows 2008 */
+  INST_WINDOWSTYPE_7            /* Windows 7 */
 } inst_windowstype;
 inst_err inst_windowstype_init(inst_windowstype *ptype)
 {
@@ -220,6 +229,10 @@ inst_err inst_windowstype_init(inst_windowstype *ptype)
         type = INST_WINDOWSTYPE_XP;
       } else if (verInfo.dwMajorVersion == 5 && verInfo.dwMinorVersion == 2) {
         type = INST_WINDOWSTYPE_2003;
+      } else if (verInfo.dwMajorVersion == 6 && verInfo.dwMinorVersion == 0) {
+        type = INST_WINDOWSTYPE_2008;
+      } else if (verInfo.dwMajorVersion == 6 && verInfo.dwMinorVersion == 1) {
+        type = INST_WINDOWSTYPE_7;
       }
       break;
   }
@@ -912,6 +925,7 @@ inst_err inst_path_copy_cd_pf(inst_buf *pfrom,
 inst_err inst_path_copy_cd_pf_all(void)
 {
   inst_buf msg, from, to;
+  inst_windowstype windowstype;
 
   inst_er(inst_buf_init(&msg));
   inst_er(inst_buf_append_string("Copying files under ", &msg));
@@ -960,18 +974,38 @@ inst_err inst_path_copy_cd_pf_all(void)
   inst__buf_reinit(&from);
   inst_er(inst_buf_append_string("src\\netwib-bin_windows\\dll", &from));
   inst__buf_reinit(&to);
-  /* Note : Windows NT 4.0 needs "netwib\\" instead of "netwib\\dll" */
-  inst_er(inst_buf_append_string("netwib\\", &to));
+  /* Note : Windows NT 4.0 needs "netwib\\" instead of "netwib\\dll".
+     Windows 7 needs "netwib\\dll". I'm unsure for other systems. */
+  inst_er(inst_windowstype_init(&windowstype));
+  switch(windowstype) {
+  case INST_WINDOWSTYPE_NT4 :
+    inst_er(inst_buf_append_string("netwib\\", &to));
+    break;
+  default :
+    inst_er(inst_buf_append_string("netwib\\dll", &to));
+  }
   inst_er(inst_path_copy_cd_pf(&from, &to, INST_FALSE));
   inst__buf_reinit(&from);
   inst_er(inst_buf_append_string("src\\netwib-bin_windows\\include", &from));
   inst__buf_reinit(&to);
-  inst_er(inst_buf_append_string("netwib\\", &to));
+  switch(windowstype) {
+  case INST_WINDOWSTYPE_NT4 :
+    inst_er(inst_buf_append_string("netwib\\", &to));
+    break;
+  default :
+    inst_er(inst_buf_append_string("netwib\\include", &to));
+  }
   inst_er(inst_path_copy_cd_pf(&from, &to, INST_FALSE));
   inst__buf_reinit(&from);
   inst_er(inst_buf_append_string("src\\netwib-bin_windows\\lib", &from));
   inst__buf_reinit(&to);
-  inst_er(inst_buf_append_string("netwib\\", &to));
+  switch(windowstype) {
+  case INST_WINDOWSTYPE_NT4 :
+    inst_er(inst_buf_append_string("netwib\\", &to));
+    break;
+  default :
+    inst_er(inst_buf_append_string("netwib\\lib", &to));
+  }
   inst_er(inst_path_copy_cd_pf(&from, &to, INST_FALSE));
 
   /* doc */
@@ -1021,6 +1055,10 @@ inst_err inst_shortcuts(inst_bool desktop,
   case INST_WINDOWSTYPE_2000 :
   case INST_WINDOWSTYPE_XP :
   case INST_WINDOWSTYPE_2003 :
+  case INST_WINDOWSTYPE_2008 :
+  case INST_WINDOWSTYPE_7 :
+    /* We use cmd so when the user exits, he is inside the shell,
+       so he can easilly restart netwox. */
     inst_er(inst_buf_append_string("cmd", &target));
     inst_er(inst_buf_append_string("/k \"", &arg));
     inst_er(inst_buf_append_buf(&glonetwox, &arg));
