@@ -1,20 +1,19 @@
 #################################################################
 #                             NETWAG                            #
 #                        Network toolbox                        #
-#           Copyright(c) 1999-2008 Laurent Constantin           #
-#                             -----                             #
-#  Main server   : http://www.laurentconstantin.com/            #
-#  Backup server : http://laurentconstantin.free.fr/            #
-#  [my current email address is on the web servers]             #
+#           Copyright(c) 1999-2012 Laurent CONSTANTIN           #
+#                 http://ntwag.sourceforge.net/                 #
+#                   laurentconstantin@free.fr                   #
 #                             -----                             #
 #  This file is part of Netwag.                                 #
-#  Netwag is free software; you can redistribute it and/or      #
+#  Netwag is free software: you can redistribute it and/or      #
 #  modify it under the terms of the GNU General Public License  #
-#  version 2 as published by the Free Software Foundation.      #
+#  version 3 as published by the Free Software Foundation.      #
 #  Netwag is distributed in the hope that it will be useful,    #
 #  but WITHOUT ANY WARRANTY; without even the implied warranty  #
-#  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  #
-#  the GNU General Public License for more details.             #
+#  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See #
+#  the GNU General Public License for more details              #
+#  (http://www.gnu.org/).                                       #
 #*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#
 
 #################################################################
@@ -77,7 +76,6 @@ proc netwag_gui_skeleton { pframe_notebook pframe_clipboard pframe_message } {
 
 ## Create the search notebook
 proc netwag_gui_notebook_tool_search { cf cb } {
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_listbox
   global netwag_glo_gui_bgcolor_button
@@ -96,16 +94,16 @@ proc netwag_gui_notebook_tool_search { cf cb } {
   global netwag_priv_toolsearch_type_sort
   global netwag_priv_toolsearch_type_tree
   frame $cfr.a
-  radiobutton $cfr.a.sort -text "sort" -variable netwag_session_toolsearch_type -command netwag_priv_toolsearch_radiobutton_callback -value $netwag_priv_toolsearch_type_sort -selectcolor $netwag_glo_gui_selectcolor -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
-  radiobutton $cfr.a.tree -text "tree" -variable netwag_session_toolsearch_type -command netwag_priv_toolsearch_radiobutton_callback -value $netwag_priv_toolsearch_type_tree -selectcolor $netwag_glo_gui_selectcolor -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  radiobutton $cfr.a.sort -text "sort" -variable netwag_session_toolsearch_type -command netwag_priv_toolsearch_radiobutton_callback -value $netwag_priv_toolsearch_type_sort -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  radiobutton $cfr.a.tree -text "tree" -variable netwag_session_toolsearch_type -command netwag_priv_toolsearch_radiobutton_callback -value $netwag_priv_toolsearch_type_tree -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
   pack $cfr.a.sort $cfr.a.tree -side left
   pack $cfr.a -side left
   netwag_dynhelp_init $cfr.a.sort "Show tools sorted by number."
   netwag_dynhelp_init $cfr.a.tree "Show tools in a tree."
 
   frame $cfr.c -bg $netwag_glo_gui_bgcolor_unused
-  radiobutton $cfr.c.all -text "show all" -variable netwag_priv_toolsearch_showsearch -command netwag_priv_toolsearch_radiobutton_callback -value "1" -selectcolor $netwag_glo_gui_selectcolor -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
-  radiobutton $cfr.c.search -text "search" -variable netwag_priv_toolsearch_showsearch -command netwag_priv_toolsearch_radiobutton_callback -value "2" -selectcolor $netwag_glo_gui_selectcolor -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  radiobutton $cfr.c.all -text "show all" -variable netwag_priv_toolsearch_showsearch -command netwag_priv_toolsearch_radiobutton_callback -value "1" -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  radiobutton $cfr.c.search -text "search" -variable netwag_priv_toolsearch_showsearch -command netwag_priv_toolsearch_radiobutton_callback -value "2" -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
   set cfrbe $cfr.c.entry
   global netwag_priv_toolsearch_searchentry ; set netwag_priv_toolsearch_searchentry $cfrbe
   entry $cfrbe -textvariable netwag_priv_toolsearch_searchvar -width 15 -font myfont -bg $netwag_glo_gui_bgcolor_text_edit -highlightthickness 0
@@ -317,7 +315,6 @@ proc netwag_gui_notebook_tool_history { cf cb } {
 ## Create the tool notebook
 proc netwag_gui_notebook_tool { cf cb } {
   global netwag_glo_gui_toolcmd_height
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_button
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_text_edit
@@ -364,7 +361,7 @@ proc netwag_gui_notebook_tool { cf cb } {
   pack $cfrt -side left -expand 1 -fill both
   pack $cfr.left.scro -side left -fill y
   button $cfr.right.run -text "Run" -command netwag_priv_toolcmd_run -font myfont -bg $netwag_glo_gui_bgcolor_button -highlightthickness 0
-  checkbutton $cfr.right.runnw -text "NW" -variable netwag_priv_toolcmd_nw -font myfont -selectcolor $netwag_glo_gui_selectcolor -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  checkbutton $cfr.right.runnw -text "NW" -variable netwag_priv_toolcmd_nw -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
   pack $cfr.right.run $cfr.right.runnw -fill x
   netwag_dynhelp_init $cfrt "Tool to run. For example :\n1\n3 1.2.3.4\nThose are equivalent to \"netwox 1\" and \"netwox 3 1.2.3.4\""
   netwag_dynhelp_init $cfr.right.run "Run the current command and add it in the history."
@@ -379,7 +376,6 @@ proc netwag_gui_notebook_infol { cf cb } {
   global netwag_glo_gui_bgcolor_text_edit
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_button
-  global netwag_glo_gui_selectcolor
 
   frame $cf.top -bg $netwag_glo_gui_bgcolor_unused
   frame $cf.text
@@ -423,7 +419,6 @@ proc netwag_gui_notebook_infor { cf cb } {
   global netwag_glo_gui_bgcolor_text_edit
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_button
-  global netwag_glo_gui_selectcolor
 
   frame $cf.top -bg $netwag_glo_gui_bgcolor_unused
   frame $cf.text
@@ -551,7 +546,6 @@ proc netwag_gui_message { frame_message } {
 ## Create the menu
 proc netwag_gui_menu { } {
   global netwag_session_helpdyn_active
-  global netwag_glo_gui_selectcolormenu
 
   set topmenu ".m"
   set topmenufile "$topmenu.file"
@@ -593,10 +587,10 @@ proc netwag_gui_menu { } {
   menu $topmenuopt -tearoff 0 -font myfont
   $topmenuopt add command -label "Font..." -command netwag_menu_optfont -underline 0 -accelerator "Ctrl-T"
   bind . <Control-t> netwag_menu_optfont
-  $topmenuopt add checkbutton -label "Dynamic help" -variable netwag_session_dynhelp_active -selectcolor $netwag_glo_gui_selectcolormenu -underline 0
+  $topmenuopt add checkbutton -label "Dynamic help" -variable netwag_session_dynhelp_active -underline 0
 
   menu $topmenuhelp -tearoff 0 -font myfont
-  $topmenuhelp add checkbutton -label "Dynamic help" -variable netwag_session_dynhelp_active -selectcolor $netwag_glo_gui_selectcolormenu -underline 0
+  $topmenuhelp add checkbutton -label "Dynamic help" -variable netwag_session_dynhelp_active -underline 0
   $topmenuhelp add command -label "Documentation" -command netwag_menu_helpdoc -underline 1
   $topmenuhelp add command -label "About netwag..." -command netwag_menu_helpabout -underline 0
 
