@@ -1,20 +1,19 @@
 #################################################################
 #                             NETWAG                            #
 #                        Network toolbox                        #
-#           Copyright(c) 1999-2008 Laurent Constantin           #
-#                             -----                             #
-#  Main server   : http://www.laurentconstantin.com/            #
-#  Backup server : http://laurentconstantin.free.fr/            #
-#  [my current email address is on the web servers]             #
+#           Copyright(c) 1999-2012 Laurent CONSTANTIN           #
+#                 http://ntwag.sourceforge.net/                 #
+#                   laurentconstantin@free.fr                   #
 #                             -----                             #
 #  This file is part of Netwag.                                 #
-#  Netwag is free software; you can redistribute it and/or      #
+#  Netwag is free software: you can redistribute it and/or      #
 #  modify it under the terms of the GNU General Public License  #
-#  version 2 as published by the Free Software Foundation.      #
+#  version 3 as published by the Free Software Foundation.      #
 #  Netwag is distributed in the hope that it will be useful,    #
 #  but WITHOUT ANY WARRANTY; without even the implied warranty  #
-#  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  #
-#  the GNU General Public License for more details.             #
+#  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See #
+#  the GNU General Public License for more details              #
+#  (http://www.gnu.org/).                                       #
 #*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#
 
 #################################################################
@@ -44,11 +43,10 @@ set netwag_priv_toolform_hidden_pattern(1) "--"
 proc netwag_common_toolform_add_left_key { numobj key } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
 
   set f1 $netwag_priv_toolform_cvf.key($numobj)
-  checkbutton $f1 -text "" -variable netwag_priv_toolform_info($numobj,isset) -font myfont -selectcolor $netwag_glo_gui_selectcolor -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0 -justify left -takefocus 0
+  checkbutton $f1 -text "" -variable netwag_priv_toolform_info($numobj,isset) -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0 -justify left -takefocus 0
   netwag_mw_form $f1
   netwag_dynhelp_init $f1 "Indicates if this line has to be generated."
   grid $f1 -row $numobj -column 1 -sticky ns
@@ -64,7 +62,6 @@ proc netwag_common_toolform_del_left_key { numobj } {
 proc netwag_common_toolform_add_right_title { numobj title } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
 
   set f3 $netwag_priv_toolform_cvf.title($numobj)
@@ -111,7 +108,6 @@ proc netwag_common_toolform_entry_tab { c } {
 proc netwag_toolform_add_button { isreq key name title defaultval } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
 
   global netwag_priv_toolform_numobj ; set numobj $netwag_priv_toolform_numobj
@@ -121,7 +117,7 @@ proc netwag_toolform_add_button { isreq key name title defaultval } {
 
   # create "[X]"
   set f2 $netwag_priv_toolform_cvf.button($numobj)
-  checkbutton $f2 -text "" -variable netwag_priv_toolform_info($numobj,var) -font myfont -selectcolor $netwag_glo_gui_selectcolor -bg $netwag_glo_gui_bgcolor_unused -wraplen 0 -justify left -command "set netwag_priv_toolform_info($numobj,isset) 1"
+  checkbutton $f2 -text "" -variable netwag_priv_toolform_info($numobj,var) -font myfont -bg $netwag_glo_gui_bgcolor_unused -wraplen 0 -justify left -command "set netwag_priv_toolform_info($numobj,isset) 1"
   netwag_mw_form $f2
   netwag_dynhelp_init $f2 "Check or uncheck this button to set or unset variable described on right."
   grid $f2 -row $numobj -column 2 -sticky wens
@@ -178,14 +174,13 @@ proc netwag_toolform_resize_button { numobj } {
 proc netwag_toolform_add_radio { numradio isreq key name title defaultval } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
 
   global netwag_priv_toolform_numobj ; set numobj $netwag_priv_toolform_numobj
 
   # create "[X]"
   set f2 $netwag_priv_toolform_cvf.button($numobj)
-  radiobutton $f2 -text "" -variable netwag_priv_toolform_info(radio,$numradio) -font myfont -selectcolor $netwag_glo_gui_selectcolor -bg $netwag_glo_gui_bgcolor_unused -wraplen 0 -justify left -command "set netwag_priv_toolform_info(radio,$numradio,set) 1" -value $name -activebackground $netwag_glo_gui_bgcolor_unused
+  radiobutton $f2 -text "" -variable netwag_priv_toolform_info(radio,$numradio) -font myfont -bg $netwag_glo_gui_bgcolor_unused -wraplen 0 -justify left -command "set netwag_priv_toolform_info(radio,$numradio,set) 1" -value $name -activebackground $netwag_glo_gui_bgcolor_unused
   netwag_mw_form $f2
   netwag_dynhelp_init $f2 "Check or uncheck this button to set variable described on right."
   grid $f2 -row $numobj -column 2 -sticky wens
@@ -332,7 +327,6 @@ proc netwag_toolform_add_entry_hist { numobj } {
 proc netwag_toolform_add_entry { enttype isreq key name title defaultval } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_text_edit
   global netwag_glo_gui_bgcolor_button
@@ -351,7 +345,7 @@ proc netwag_toolform_add_entry { enttype isreq key name title defaultval } {
   bind $f2.e <Key> "if {\[netwag_common_toolform_entry_tab %K\]} { set netwag_priv_toolform_info($numobj,isset) 1 }"
   netwag_mw_form $f2.e
   pack $f2.e -side left -expand 1 -fill x
-  netwag_dynhelp_init $f2.e "Enter value you want in this field."
+  netwag_dynhelp_init $f2.e "Enter the value you want in this field."
   # *
   label $f2.show -relief raised -text "*" -font myfont -bg $netwag_glo_gui_bgcolor_button -highlightthickness 0
   eval "bind $f2.show <Button-1> {netwag_toolform_add_entry_show $numobj}"
@@ -500,7 +494,6 @@ proc netwag_toolform_resize_entry { numobj } {
 proc netwag_toolform_add_listbox { isreq key name title listval defaultval } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_listbox
 
@@ -625,7 +618,6 @@ proc netwag_toolform_resize_listbox { numobj } {
 proc netwag_toolform_add_more { title defaultval } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_text_edit
 
@@ -696,7 +688,6 @@ proc netwag_toolform_resize_more { numobj } {
 proc netwag_toolform_add_text { txt } {
   global netwag_priv_toolform_cvf
   global netwag_priv_toolform_info
-  global netwag_glo_gui_selectcolor
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_text_edit
 
