@@ -1,20 +1,19 @@
 #################################################################
 #                             NETWAG                            #
 #                        Network toolbox                        #
-#           Copyright(c) 1999-2008 Laurent Constantin           #
-#                             -----                             #
-#  Main server   : http://www.laurentconstantin.com/            #
-#  Backup server : http://laurentconstantin.free.fr/            #
-#  [my current email address is on the web servers]             #
+#           Copyright(c) 1999-2012 Laurent CONSTANTIN           #
+#                 http://ntwag.sourceforge.net/                 #
+#                   laurentconstantin@free.fr                   #
 #                             -----                             #
 #  This file is part of Netwag.                                 #
-#  Netwag is free software; you can redistribute it and/or      #
+#  Netwag is free software: you can redistribute it and/or      #
 #  modify it under the terms of the GNU General Public License  #
-#  version 2 as published by the Free Software Foundation.      #
+#  version 3 as published by the Free Software Foundation.      #
 #  Netwag is distributed in the hope that it will be useful,    #
 #  but WITHOUT ANY WARRANTY; without even the implied warranty  #
-#  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  #
-#  the GNU General Public License for more details.             #
+#  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See #
+#  the GNU General Public License for more details              #
+#  (http://www.gnu.org/).                                       #
 #*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#
 
 #################################################################
@@ -109,7 +108,6 @@ proc netwag_priv_txtfind_popup { } {
   global netwag_glo_gui_bgcolor_button
   global netwag_glo_gui_bgcolor_unused
   global netwag_glo_gui_bgcolor_text_edit
-  global netwag_glo_gui_selectcolor
   global netwag_priv_txtfind_config_w
   global netwag_priv_txtfind_config_txt
   global netwag_priv_txtfind_config_nocase
@@ -157,9 +155,9 @@ proc netwag_priv_txtfind_popup { } {
   frame $fwblf2 -bg $netwag_glo_gui_bgcolor_unused
   frame $fwblf3 -bg $netwag_glo_gui_bgcolor_unused
   pack $fwblf1 $fwblf2 $fwblf3 -fill x -expand 1 -anchor w
-  checkbutton $fwbln -text "nocase" -variable netwag_priv_txtfind_config_nocase -font myfont -selectcolor $netwag_glo_gui_selectcolor -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
-  checkbutton $fwblr -text "regexp" -variable netwag_priv_txtfind_config_regexp -font myfont -selectcolor $netwag_glo_gui_selectcolor -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
-  checkbutton $fwblb -text "back" -variable netwag_priv_txtfind_config_back -font myfont -selectcolor $netwag_glo_gui_selectcolor -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  checkbutton $fwbln -text "nocase" -variable netwag_priv_txtfind_config_nocase -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  checkbutton $fwblr -text "regexp" -variable netwag_priv_txtfind_config_regexp -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
+  checkbutton $fwblb -text "back" -variable netwag_priv_txtfind_config_back -font myfont -bg $netwag_glo_gui_bgcolor_unused -highlightthickness 0
   pack $fwbln $fwblr $fwblb -side left
   netwag_dynhelp_init $fwbln "Search ignoring case"
   netwag_dynhelp_init $fwblr "Search using a regular expression"
