@@ -19,7 +19,7 @@ netwib_err netwib_buf_append_kbd(netwib_constbuf *pmessage,
 #define NETWIB_BUF_APPEND_KBD_NODEF NULL
 
 /*-------------------------------------------------------------*/
-/* Name : netwib_buf_append_passwd
+/* Name : netwib_buf_append_password
    Description :
      Ask user to enter a password on keyboard.
    Input parameter(s) :
@@ -30,7 +30,8 @@ netwib_err netwib_buf_append_kbd(netwib_constbuf *pmessage,
      pbuf : output buffer set with the text
    Normal return values :
      NETWIB_ERR_OK : ok
+   This function sets NETWIB_BUF_FLAGS_SENSITIVE.
 */
-netwib_err netwib_buf_append_passwd(netwib_constbuf *pmessage,
-                                    netwib_constbuf *pdefaulttext,
-                                    netwib_buf *pbuf);
+netwib_err netwib_buf_append_password(netwib_constbuf *pmessage,
+                                      netwib_constbuf *pdefaulttext,
+                                      netwib_buf *pbuf);
