@@ -87,8 +87,59 @@ typedef const netwib_buf netwib_constbuf;
 */
 #define NETWIB_BUF_FLAGS_CANSLIDE 0x00000004u
 
-/* currently unused */
-#define NETWIB_BUF_FLAGS_UNUSED 0xFFFFFFF1u
+/* Sometimes, a buffer contains sensitive data such as a password,
+   so we want to do a memset on this data when it is no more needed.
+   This flags says that buffer contains sensitive data. Buffer will
+   be wiped with memset(.0.) during:
+     netwib_buf_close(),
+     netwib__buf_reinit(),
+     netwib__buf_erase(),
+     netwib_bufpool_buf_close(),
+     netwib_bufpool_close(),
+     and all functions using above ones.
+   It is developer's task to set this flag each time a buffer may
+   contain sensitive data.
+   Netwib supports a feature to transfer this flag (also known as
+   tainting in other languages). For example, when a sensitive
+   buffer is copied to another buffer, this one also becomes
+   sensitive.
+   Once buffer is closed, the flag is unset, so user has to set
+   it each time sensitive data is initialized. The closing
+   functions are:
+     netwib_buf_close(),
+     netwib_bufpool_buf_close(),
+     netwib_bufpool_close().
+   WARNING:
+   This feature was conceived for PASSWORDS or cryptographic KEYS
+   stored in a netwib_buf. It cannot help for other types such
+   as a netwib_string, a netwib_ring or a netwib_ip.
+   This feature was conceived for buffer manipulation functions,
+   such as netwib_buf_append_buf, and not in functions unrelated
+   to passwords or keys, such as netwib_pkt_... or
+   netwib_sniff_... When a function supports this feature, it is
+   indicated in its help comment before the prototype (.h file).
+   Perhaps one day, I will expand this feature to erase other kind
+   of data, but this is not the case currently.
+   To sum up, don't expect this feature to be the Solution for
+   your sensitive data management, but only a small step towards it.
+   END OF WARNING.
+   This flag defaults to false. It has to be explicitly set
+   by user.
+*/
+#define NETWIB_BUF_FLAGS_SENSITIVE 0x00000008u
+/* data is sensitive, but readonly (such as a password stored
+   in a static string which cannot be wiped, but can be
+   transfered when buffer is copied)
+*/
+#define NETWIB_BUF_FLAGS_SENSITIVE_READONLY 0x00000010u
+/* to transfer the sensitive flag to the second buffer */
+#define netwib__buf_transfersensitive(pbuf1,pbuf2) { if ((pbuf1) != NULL && (pbuf2) != NULL) { if ((pbuf1)->flags & NETWIB_BUF_FLAGS_SENSITIVE) { (pbuf2)->flags |= NETWIB_BUF_FLAGS_SENSITIVE; } } }
+/* to wipe a local array used in parallel of a buffer */
+#define netwib__localarray_wipe(arr) netwib_c_memset((arr),0,sizeof(arr))
+#define netwib__localarray_ifbuf_wipe(pbuf,arr) { if ((pbuf) != NULL && ((pbuf)->flags & NETWIB_BUF_FLAGS_SENSITIVE)) netwib__localarray_wipe(arr); }
+
+/* number of used bits */
+#define NETWIB_BUF_FLAGS_USEDBITS 5
 
 /*-------------------------------------------------------------*/
 /***************************************************************
@@ -124,7 +175,7 @@ typedef netwib_buf netwib_bufext;
 */
 netwib_err netwib_buf_init_malloc(netwib_uint32 allocs,
                                   netwib_buf *pbuf);
-#define netwib_buf_init_mallocdefault(pbuf) netwib_buf_init_malloc(0,pbuf)
+#define netwib_buf_init_mallocdefault(pbuf) netwib_buf_init_malloc(1024,pbuf)
 
 /*-------------------------------------------------------------*/
 /* Name : netwib_buf_init_ext_array
@@ -132,7 +183,7 @@ netwib_err netwib_buf_init_malloc(netwib_uint32 allocs,
      Initialize a buf. Its memory corresponds to an external
      fixed size array.
    Input parameter(s) :
-     arrayptr : external array
+     array : external array
      arraysize : external array size
      beginoffset : offset of begin in this array
      endoffset : offset of end in this array
@@ -142,23 +193,62 @@ netwib_err netwib_buf_init_malloc(netwib_uint32 allocs,
    Normal return values :
      NETWIB_ERR_OK : ok
 */
-netwib_err netwib_buf_init_ext_array(netwib_constptr arrayptr,
+netwib_err netwib_buf_init_ext_array(netwib_constptr array,
                                      netwib_uint32 arraysize,
                                      netwib_uint32 beginoffset,
                                      netwib_uint32 endoffset,
                                      netwib_bufext *pbuf);
-#define netwib_buf_init_ext_arrayempty(arrayptr,arraysize,pbuf) netwib_buf_init_ext_array(arrayptr,arraysize,0,0,pbuf)
-#define netwib_buf_init_ext_arrayfilled(arrayptr,arraysize,pbuf) netwib_buf_init_ext_array(arrayptr,arraysize,0,arraysize,pbuf)
-/* This one permits to easily use netwib_buf_ref_string because
-   there is room left for the '\0' */
-#define netwib_buf_init_ext_datafilled(dataptr,datasize,pbuf) netwib_buf_init_ext_array(dataptr,datasize+1,0,datasize,pbuf)
-/* This one creates pbuf which refers data from pbufin */
-#define netwib_buf_init_ext_buf(pbufin,pbuf) netwib_buf_init_ext_arrayfilled(netwib__buf_ref_data_ptr(pbufin),netwib__buf_ref_data_size(pbufin),pbuf)
+#define netwib_buf_init_ext_arrayempty(array,arraysize,pbuf) netwib_buf_init_ext_array(array,arraysize,0,0,pbuf)
+#define netwib_buf_init_ext_arrayfilled(array,arraysize,pbuf) netwib_buf_init_ext_array(array,arraysize,0,arraysize,pbuf)
+#define netwib_buf_init_ext_arraysizeofempty(array,pbuf) netwib_buf_init_ext_arrayempty(array,sizeof(array),pbuf)
+#define netwib_buf_init_ext_arraysizeoffilled(array,pbuf) netwib_buf_init_ext_arrayfilled(array,sizeof(array),pbuf)
 /* A buffer containing no data */
 #define netwib_buf_init_ext_empty(pbuf) netwib_buf_init_ext_array(NULL,0,0,0,pbuf)
 
 /*-------------------------------------------------------------*/
-/* Name : netwib_buf_init_ext_text
+/* Name : netwib_buf_init_ext_storagearray
+   Description :
+     Initialize a buf. Its memory corresponds to an external
+     fixed size array or to nothing. When data is added, it may
+     be allocated. A call to netwib_buf_close() will have to be done.
+   Input parameter(s) :
+     array : external array
+     arraysize : external array size
+     beginoffset : offset of begin in this array
+     endoffset : offset of end in this array
+   Input/output parameter(s) :
+   Output parameter(s) :
+     *pbuf : netwib_bufext initialized
+   Normal return values :
+     NETWIB_ERR_OK : ok
+*/
+netwib_err netwib_buf_init_ext_storagearray(netwib_constptr array,
+                                            netwib_uint32 arraysize,
+                                            netwib_bufext *pbuf);
+/* An empty buffer, allocated on first append */
+#define netwib_buf_init_ext_storage(pbuf) netwib_buf_init_ext_storagearray(NULL,0,pbuf)
+/* An empty array, allocated if not sufficiently big */
+#define netwib_buf_init_ext_storagearraysizeof(array,pbuf) netwib_buf_init_ext_storagearray(array,sizeof(array),pbuf)
+
+/*-------------------------------------------------------------*/
+/* Name : netwib_buf_init_ext_buf
+   Description :
+     Initialize a buf. Its memory corresponds to an external
+     buffer.
+   Input parameter(s) :
+     *pbuf : netwib_buf containing data
+   Input/output parameter(s) :
+   Output parameter(s) :
+     *pbuf : netwib_bufext initialized
+   Normal return values :
+     NETWIB_ERR_OK : ok
+   This function supports NETWIB_BUF_FLAGS_SENSITIVE.
+*/
+netwib_err netwib_buf_init_ext_buf(netwib_constbuf *pbufin,
+                                   netwib_bufext *pbuf);
+
+/*-------------------------------------------------------------*/
+/* Name : netwib_buf_init_ext_string
    Description :
      Initialize a buf. Its memory corresponds to an external
      preset string.
@@ -170,8 +260,8 @@ netwib_err netwib_buf_init_ext_array(netwib_constptr arrayptr,
    Normal return values :
      NETWIB_ERR_OK : ok
 */
-netwib_err netwib_buf_init_ext_text(netwib_conststring str,
-                                    netwib_bufext *pbuf);
+netwib_err netwib_buf_init_ext_string(netwib_conststring str,
+                                      netwib_bufext *pbuf);
 
 /*-------------------------------------------------------------*/
 /* Name : netwib_buf_append_xyz
@@ -187,12 +277,13 @@ netwib_err netwib_buf_init_ext_text(netwib_conststring str,
    Output parameter(s) :
    Normal return values :
      NETWIB_ERR_OK : ok
+   The netwib_buf_append_buf function supports NETWIB_BUF_FLAGS_SENSITIVE.
 */
 netwib_err netwib_buf_append_data(netwib_constdata data,
                                   netwib_uint32 datasize,
                                   netwib_buf *pbuf);
-netwib_err netwib_buf_append_text(netwib_conststring str,
-                                  netwib_buf *pbuf);
+netwib_err netwib_buf_append_string(netwib_conststring str,
+                                    netwib_buf *pbuf);
 netwib_err netwib_buf_append_buf(netwib_constbuf *pbuftoappend,
                                  netwib_buf *pbuf);
 netwib_err netwib_buf_append_byte(netwib_byte b,
@@ -211,6 +302,7 @@ netwib_err netwib_buf_append_byte(netwib_byte b,
    Note :
      Parameter canslide has no effect on this function (this is
      logical).
+   This function supports NETWIB_BUF_FLAGS_SENSITIVE.
 */
 netwib_err netwib_buf_prepend_buf(netwib_constbuf *pbuftoprepend,
                                   netwib_buf *pbuf);
@@ -230,16 +322,29 @@ netwib_err netwib_buf_prepend_buf(netwib_constbuf *pbuftoprepend,
    Normal return values :
      NETWIB_ERR_OK : ok
      NETWIB_ERR_DATANOSPACE : no room for the '\0'
-   Note: pbuf is const (netwib_constbuf), but if fact it is
-         modified because a '\0' is added. However, as the
-         addition is after endoffset, pbuf's value is not
-         really changed. If your pbuf contains valuable info
-         after endoffset, just copy it or use function
-         netwib_buf_init_ext_buf.
 */
-netwib_err netwib_buf_ref_string(netwib_constbuf *pbuf,
+netwib_err netwib_buf_ref_string(netwib_buf *pbuf,
                                  netwib_string *pstr);
 
+/*-------------------------------------------------------------*/
+/* Name : netwib_constbuf_ref_string
+   Description :
+     Some as netwib_buf_ref_string except it does not modify
+     the buffer to add the '\0'.
+   Input parameter(s) :
+     *pbuf : buffer
+   Input/output parameter(s) :
+   Output parameter(s) :
+     *pstr : pointer to start of string
+   Normal return values :
+     NETWIB_ERR_OK : ok
+     NETWIB_ERR_DATANOSPACE : the char after endoffset is not a '\0'
+*/
+netwib_err netwib_constbuf_ref_string(netwib_constbuf *pbuf,
+                                      netwib_string *pstr);
+/* to use at begin of a function to manage a local buffer */
+#define netwib__constbuf_ref_string(pbuf, str, bufstorage, func) { netwib_err bufstorageret; bufstorageret = netwib_constbuf_ref_string(pbuf, &str); if (bufstorageret != NETWIB_ERR_OK) { if (bufstorageret == NETWIB_ERR_DATANOSPACE) { netwib_data bufstoragearray[512]; netwib_buf bufstorage; netwib_er(netwib_buf_init_ext_storagearraysizeof(bufstoragearray, &bufstorage)); netwib_er(netwib_buf_append_buf(pbuf, &bufstorage)); netwib_er(netwib_buf_append_byte(0, &bufstorage)); bufstorage.endoffset--; bufstorageret = func; netwib_er(netwib_buf_close(&bufstorage)); } return(bufstorageret); } }
+
 /*-------------------------------------------------------------*/
 /* Name : netwib_buf_wantspace
    Description :
@@ -309,12 +414,12 @@ netwib_err netwib_buf_casecmp(netwib_constbuf *pbuf1,
                               netwib_constbuf *pbuf2,
                               netwib_cmp *pcmp);
 /* compare to a string */
-netwib_err netwib_buf_cmp_str(netwib_constbuf *pbuf1,
-                              netwib_conststring string2,
-                              netwib_cmp *pcmp);
-netwib_err netwib_buf_casecmp_str(netwib_constbuf *pbuf1,
-                                  netwib_conststring string2,
-                                  netwib_cmp *pcmp);
+netwib_err netwib_buf_cmp_string(netwib_constbuf *pbuf1,
+                                 netwib_conststring string2,
+                                 netwib_cmp *pcmp);
+netwib_err netwib_buf_casecmp_string(netwib_constbuf *pbuf1,
+                                     netwib_conststring string2,
+                                     netwib_cmp *pcmp);
 
 /*-------------------------------------------------------------*/
 /* Name : netwib_buf_shift
@@ -364,8 +469,8 @@ netwib_err netwib_buf_close(netwib_buf *pbuf);
 
 /*-------------------------------------------------------------*/
 /* Frequently needed defines */
-#define netwib__buf_reinit(pbuf) (pbuf)->beginoffset = 0; (pbuf)->endoffset = 0;
-#define netwib__buf_erase(pbuf) (pbuf)->endoffset = (pbuf)->beginoffset;
+#define netwib__buf_reinit(pbuf) { (pbuf)->beginoffset = 0; (pbuf)->endoffset = 0; if (((pbuf)->flags & NETWIB_BUF_FLAGS_SENSITIVE) && !((pbuf)->flags & NETWIB_BUF_FLAGS_SENSITIVE_READONLY)) { netwib_c_memset((pbuf)->totalptr, 0, (pbuf)->totalsize); } }
+#define netwib__buf_erase(pbuf) { if (((pbuf)->flags & NETWIB_BUF_FLAGS_SENSITIVE) && !((pbuf)->flags & NETWIB_BUF_FLAGS_SENSITIVE_READONLY)) { netwib_c_memset((pbuf)->totalptr+(pbuf)->beginoffset, 0, (pbuf)->endoffset-(pbuf)->beginoffset); } (pbuf)->endoffset = (pbuf)->beginoffset; }
 #define netwib__buf_ref_data_ptr(pbuf) ((pbuf)->totalptr + (pbuf)->beginoffset)
 #define netwib__buf_ref_data_size(pbuf) ((pbuf)->endoffset -(pbuf)->beginoffset)
 #define netwib__buf_ref_data_sizenull(pbuf) ((pbuf)!=NULL?netwib__buf_ref_data_size(pbuf):0)
