@@ -26,20 +26,20 @@
 
 /*-------------------------------------------------------------*/
 /* 0->16 to '0'->'F' without error checking */
-#define netwib_c2_16toc(x) (char)((x<=9)?('0'+x):('a'+x-10))
-#define netwib_c2_16toC(x) (char)((x<=9)?('0'+x):('A'+x-10))
+#define netwib_c2_16toc(x) (char)(((x)<=9)?('0'+(x)):('a'+(x)-10))
+#define netwib_c2_16toC(x) (char)(((x)<=9)?('0'+(x)):('A'+(x)-10))
 /* '0'->'F' to 0->16 without error checking */
-#define netwib_c2_cto16(x) ((x>='0'&&x<='9')?(x-'0'):((x>='a'&&x<='f')?(10+x-'a'):(10+x-'A')))
+#define netwib_c2_cto16(x) (((x)>='0'&&(x)<='9')?((x)-'0'):(((x)>='a'&&(x)<='f')?(10+(x)-'a'):(10+(x)-'A')))
 /* 0->9 to '0'->'9' without error checking */
-#define netwib_c2_9toc(x) (char)('0'+x)
+#define netwib_c2_9toc(x) (char)('0'+(x))
 /* '0'->'9' to 0->9 without error checking */
-#define netwib_c2_cto9(x) (x-'0')
+#define netwib_c2_cto9(x) ((x)-'0')
 
 /*-------------------------------------------------------------*/
 /* '0'->'F' to 0->16 with error checking */
-#define netwib_c2_cto16_if(c,quartet) if (c >= '0' && c <= '9') { quartet = c - '0'; } else if (c >= 'a' && c <= 'f') { quartet = 10 + c - 'a'; } else if (c >= 'A' && c <= 'F') { quartet = 10 + c - 'A'; }
+#define netwib_c2_cto16_if(c,quartet) if ((c) >= '0' && (c) <= '9') { quartet = (c) - '0'; } else if ((c) >= 'a' && (c) <= 'f') { quartet = 10 + (c) - 'a'; } else if ((c) >= 'A' && (c) <= 'F') { quartet = 10 + (c) - 'A'; }
 /* '0'->'9' to 0->9 with error checking */
-#define netwib_c2_cto9_if(c,digit) if (c >= '0' && c <= '9') { digit = c - '0'; }
+#define netwib_c2_cto9_if(c,digit) if ((c) >= '0' && (c) <= '9') { digit = (c) - '0'; }
 
 /*-------------------------------------------------------------*/
 /* INTEGER FUNCTIONS */
