@@ -1,24 +1,20 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2008 Laurent Constantin
-                                  -----
-
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwib.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
   This file is part of Netwib.
 
-  Netwib is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwib is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwib is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -364,16 +360,14 @@ netwib_err netwib_ring_index_add_after(netwib_ring_index *pringindex,
 netwib_err netwib_ring_index_this_value(netwib_ring_index *pringindex,
                                         netwib_ptr *ppitem)
 {
-  netwib_ring *pring;
 
   /* parameter verification */
   if (pringindex == NULL) {
     return(NETWIB_ERR_PANULLPTR);
   }
-  pring = pringindex->pring;
 #if NETWIB_DEBUG_LEAK==1
   netwib_er(netwib_debug_leak_valid_ringi(pringindex));
-  netwib_er(netwib_debug_leak_valid_ring(pring));
+  netwib_er(netwib_debug_leak_valid_ring(pringindex->pring));
 #endif
 
   if (pringindex->pcurrentitem == NULL) {
