@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /* IPv6 not yet supported because I never had access to a computer with IPv6 */
@@ -21,7 +21,7 @@ static netwib_err netwib_priv_conf_netstatin(netwib_priv_confwork *pcw)
   netwib_bool pcdset, pciset;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("/usr/bin/netstat -in", &buf));
+  netwib_er(netwib_buf_init_ext_string("/usr/bin/netstat -in", &buf));
   ret = netwib_io_init_exec(&buf, NETWIB_IO_WAYTYPE_READ, NETWIB_FALSE,
                             NULL, NULL, &piofile);
   if (ret != NETWIB_ERR_OK) {
@@ -155,7 +155,7 @@ static netwib_err netwib_priv_conf_lanscanmai(netwib_priv_confwork *pcw)
   netwib_bool pcdset, setatleastone;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("/usr/sbin/lanscan -mai", &buf));
+  netwib_er(netwib_buf_init_ext_string("/usr/sbin/lanscan -mai", &buf));
   ret = netwib_io_init_exec(&buf, NETWIB_IO_WAYTYPE_READ, NETWIB_FALSE,
                             NULL, NULL, &piofile);
   if (ret != NETWIB_ERR_OK) {
@@ -243,7 +243,7 @@ static netwib_err netwib_priv_conf_lanscanai(netwib_priv_confwork *pcw)
   netwib_bool pcdset;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("/usr/sbin/lanscan -ai", &buf));
+  netwib_er(netwib_buf_init_ext_string("/usr/sbin/lanscan -ai", &buf));
   ret = netwib_io_init_exec(&buf, NETWIB_IO_WAYTYPE_READ, NETWIB_FALSE,
                             NULL, NULL, &piofile);
   if (ret != NETWIB_ERR_OK) {
@@ -324,7 +324,7 @@ static netwib_err netwib_priv_conf_arpan(netwib_priv_confwork *pcw)
   netwib_bool pcaset;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("/usr/sbin/arp -an", &buf));
+  netwib_er(netwib_buf_init_ext_string("/usr/sbin/arp -an", &buf));
   ret = netwib_io_init_exec(&buf, NETWIB_IO_WAYTYPE_READ, NETWIB_FALSE,
                             NULL, NULL, &piofile);
   if (ret != NETWIB_ERR_OK) {
@@ -400,7 +400,7 @@ static netwib_err netwib_priv_conf_netstatrvn(netwib_priv_confwork *pcw)
   netwib_bool pcrset, setatleastone;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("/usr/bin/netstat -rvn", &buf));
+  netwib_er(netwib_buf_init_ext_string("/usr/bin/netstat -rvn", &buf));
   ret = netwib_io_init_exec(&buf, NETWIB_IO_WAYTYPE_READ, NETWIB_FALSE,
                             NULL, NULL, &piofile);
   if (ret != NETWIB_ERR_OK) {
@@ -512,7 +512,7 @@ static netwib_err netwib_priv_conf_netstatrvnskip(netwib_priv_confwork *pcw)
   netwib_bool pcrset;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("/usr/bin/netstat -rvn", &buf));
+  netwib_er(netwib_buf_init_ext_string("/usr/bin/netstat -rvn", &buf));
   ret = netwib_io_init_exec(&buf, NETWIB_IO_WAYTYPE_READ, NETWIB_FALSE,
                             NULL, NULL, &piofile);
   if (ret != NETWIB_ERR_OK) {
