@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -123,7 +123,7 @@ static netwib_err netwib_priv_conf_devices_ioctl_dev(netwib_priv_confwork *pcw,
   ret = NETWIB_ERR_OK;
 
   /* set device */
-  netwib_eg(netwib_buf_append_text(device, &pcd->device));
+  netwib_eg(netwib_buf_append_string(device, &pcd->device));
   pcdset = NETWIB_TRUE;
 
   /* get hwtype */
@@ -233,7 +233,7 @@ static netwib_err netwib_priv_conf_devices_ioctl(netwib_priv_confwork *pcw)
       pci->ispointtopoint = NETWIB_TRUE;
     }
     /* get device */
-    netwib_eg(netwib_buf_append_text(ireqbuf[i].ifr_name, &pci->device));
+    netwib_eg(netwib_buf_append_string(ireqbuf[i].ifr_name, &pci->device));
     /* get ip */
     netwib_c_memset(&ifr, 0, sizeof(ifr));
     netwib_c_strcpy(ifr.ifr_name, ireqbuf[i].ifr_name);
@@ -359,7 +359,7 @@ static netwib_err netwib_priv_conf_devices_ioctl6(netwib_priv_confwork *pcw)
     netwib_eg(netwib_priv_confwork_devices_init(&pcd));
     pcdset = NETWIB_TRUE;
     /* get device */
-    netwib_eg(netwib_buf_append_text(lireqbuf[i].lifr_name, &pcd->device));
+    netwib_eg(netwib_buf_append_string(lireqbuf[i].lifr_name, &pcd->device));
     /* get hwtype */
     netwib_eg(netwib_priv_conf_devices_ioctl_hw(fd, lireqbuf[i].lifr_name,
                                                 &pcd->hwtype, &pcd->eth));
@@ -400,7 +400,7 @@ static netwib_err netwib_priv_conf_devices_ioctl6(netwib_priv_confwork *pcw)
       pci->ispointtopoint = NETWIB_TRUE;
     }
     /* get device */
-    netwib_eg(netwib_buf_append_text(lireqbuf[i].lifr_name, &pci->device));
+    netwib_eg(netwib_buf_append_string(lireqbuf[i].lifr_name, &pci->device));
     /* get ip */
     netwib_c_memset(&lifr, 0, sizeof(lifr));
     netwib_c_strcpy(lifr.lifr_name, lireqbuf[i].lifr_name);
