@@ -115,11 +115,10 @@ netwib_err netwib_priv_confwork_debug(netwib_priv_confwork *pcw,
     netwib_er(netwib_buf_append_fmt(pbuf, "  d=%{uint32},%{buf},%{buf}",
                                     pcd->devnum,
                                     &pcd->device,&pcd->deviceeasy));
-    netwib_er(netwib_buf_append_fmt(pbuf, " m=%{uint32} e=", pcd->mtu));
+    netwib_er(netwib_buf_append_fmt(pbuf, " m=%{uint32} t=", pcd->mtu));
+    netwib_er(netwib_buf_append_device_hwtype(pcd->hwtype, pbuf));
     if (pcd->hwtype == NETWIB_DEVICE_HWTYPE_ETHER) {
-      netwib_er(netwib_buf_append_fmt(pbuf, "%{eth}", &pcd->eth));
-    } else {
-      netwib_er(netwib_buf_append_device_hwtype(pcd->hwtype, pbuf));
+      netwib_er(netwib_buf_append_fmt(pbuf, ">%{eth}", &pcd->eth));
     }
     netwib_er(netwib_buf_append_string("\n", pbuf));
   }
