@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -10,8 +10,8 @@
 /*-------------------------------------------------------------*/
 static netwib_err netwib_priv_ip4_bad(netwib_conststring str)
 {
-  netwib_er(netwib_priv_errmsg_text("this is not an IPv4 address: "));
-  netwib_er(netwib_priv_errmsg_append_text(str));
+  netwib_er(netwib_priv_errmsg_string("this is not an IPv4 address: "));
+  netwib_er(netwib_priv_errmsg_append_string(str));
 
   return(NETWIB_ERR_OK);
 }
@@ -19,8 +19,8 @@ static netwib_err netwib_priv_ip4_bad(netwib_conststring str)
 /*-------------------------------------------------------------*/
 static netwib_err netwib_priv_ip6_bad(netwib_conststring str)
 {
-  netwib_er(netwib_priv_errmsg_text("this is not an IPv6 address: "));
-  netwib_er(netwib_priv_errmsg_append_text(str));
+  netwib_er(netwib_priv_errmsg_string("this is not an IPv6 address: "));
+  netwib_er(netwib_priv_errmsg_append_string(str));
 
   return(NETWIB_ERR_OK);
 }
@@ -633,7 +633,7 @@ netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
       return(NETWIB_ERR_NOTCONVERTED);
     }
 
-    ret = netwib_buf_append_text(host, pbuf);
+    ret = netwib_buf_append_string(host, pbuf);
     free(host);
   }
 #elif NETWIBDEF_HAVEFUNC_GETIPNODEBYADDR == 1
@@ -661,7 +661,7 @@ netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
       return(NETWIB_ERR_NOTCONVERTED);
     }
 
-    ret = netwib_buf_append_text(phe->h_name, pbuf);
+    ret = netwib_buf_append_string(phe->h_name, pbuf);
     freehostent(phe);
   }
 #elif NETWIBDEF_HAVEFUNC_GETHOSTBYADDR_R == 1
@@ -709,7 +709,7 @@ netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
       netwib_er(netwib_ptr_free(&ptr));
       return(NETWIB_ERR_NOTCONVERTED);
     }
-    ret = netwib_buf_append_text(entry.h_name, pbuf);
+    ret = netwib_buf_append_string(entry.h_name, pbuf);
     netwib_er(netwib_ptr_free(&ptr));
    }
 #else
@@ -730,7 +730,7 @@ netwib_err netwib_priv_ip_buf_append_hn(netwib_constip *pip,
       netwib_er(netwib_priv_glovars_other_wrunlock());
       return(NETWIB_ERR_NOTCONVERTED);
     }
-    ret = netwib_buf_append_text(phe->h_name, pbuf);
+    ret = netwib_buf_append_string(phe->h_name, pbuf);
     netwib_er(netwib_priv_glovars_other_wrunlock());
   }
 #endif
@@ -773,7 +773,7 @@ netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
       return(NETWIB_ERR_NOTCONVERTED);
     }
 
-    ret = netwib_buf_append_text(phe->h_name, pbuf);
+    ret = netwib_buf_append_string(phe->h_name, pbuf);
     i = 0;
     while (ret == NETWIB_ERR_OK) {
       pc = phe->h_aliases[i++];
@@ -782,7 +782,7 @@ netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
       }
       ret = netwib_buf_append_byte(',', pbuf);
       if (ret == NETWIB_ERR_OK) {
-        ret = netwib_buf_append_text(pc, pbuf);
+        ret = netwib_buf_append_string(pc, pbuf);
       }
     }
     freehostent(phe);
@@ -832,7 +832,7 @@ netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
       netwib_er(netwib_ptr_free(&ptr));
       return(NETWIB_ERR_NOTCONVERTED);
     }
-    ret = netwib_buf_append_text(entry.h_name, pbuf);
+    ret = netwib_buf_append_string(entry.h_name, pbuf);
     i = 0;
     while (ret == NETWIB_ERR_OK) {
       pc = entry.h_aliases[i++];
@@ -841,7 +841,7 @@ netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
       }
       ret = netwib_buf_append_byte(',', pbuf);
       if (ret == NETWIB_ERR_OK) {
-        ret = netwib_buf_append_text(pc, pbuf);
+        ret = netwib_buf_append_string(pc, pbuf);
       }
     }
     netwib_er(netwib_ptr_free(&ptr));
@@ -865,7 +865,7 @@ netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
       netwib_er(netwib_priv_glovars_other_wrunlock());
       return(NETWIB_ERR_NOTCONVERTED);
     }
-    ret = netwib_buf_append_text(phe->h_name, pbuf);
+    ret = netwib_buf_append_string(phe->h_name, pbuf);
     i = 0;
     while (ret == NETWIB_ERR_OK) {
       pc = phe->h_aliases[i++];
@@ -874,7 +874,7 @@ netwib_err netwib_priv_ip_buf_append_hns(netwib_constip *pip,
       }
       ret = netwib_buf_append_byte(',', pbuf);
       if (ret == NETWIB_ERR_OK) {
-        ret = netwib_buf_append_text(pc, pbuf);
+        ret = netwib_buf_append_string(pc, pbuf);
       }
     }
     netwib_er(netwib_priv_glovars_other_wrunlock());
@@ -1163,8 +1163,8 @@ static netwib_err netwib_priv_ip_netmaskprefix_init_bufnet(netwib_constbuf *pbuf
   netwib_err ret;
 
   /* try with "1.2.3" */
-  netwib__buf_ref_string(pbuf, s, bufstorage,
-                         netwib_priv_ip_netmaskprefix_init_bufnet(&bufstorage, pnet, pmask, pprefix));
+  netwib__constbuf_ref_string(pbuf, s, bufstorage,
+                              netwib_priv_ip_netmaskprefix_init_bufnet(&bufstorage, pnet, pmask, pprefix));
   ret = netwib_priv_ip_netmaskprefix_init_sip4(s, NETWIB_TRUE, pnet, pmask,
                                                pprefix);
   if (ret == NETWIB_ERR_OK) return(NETWIB_ERR_OK);
@@ -1247,7 +1247,7 @@ netwib_err netwib_priv_ip_netmaskprefix_init_bufdefault(netwib_iptype iptype,
 {
   netwib_cmp cmp;
 
-  netwib_er(netwib_buf_cmp_str(pbuf, "default", &cmp));
+  netwib_er(netwib_buf_cmp_string(pbuf, "default", &cmp));
   if (cmp == NETWIB_CMP_EQ) {
     switch(iptype) {
     case NETWIB_IPTYPE_IP4 :
