@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -53,9 +53,9 @@ netwib_err netwib_priv_ips_ip_init_array(netwib_byte array[],
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_ips_add_str_all(netwib_priv_ranges *pr,
-                                              netwib_conststring str,
-                                              netwib_bool usedel)
+static netwib_err netwib_priv_ips_add_string_all(netwib_priv_ranges *pr,
+                                                 netwib_conststring str,
+                                                 netwib_bool usedel)
 {
   netwib_byte infarray[NETWIB_IPS_LEN], suparray[NETWIB_IPS_LEN];
   netwib_ip ipa;
@@ -89,9 +89,9 @@ static netwib_err netwib_priv_ips_add_str_all(netwib_priv_ranges *pr,
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_ips_add_str_ip4(netwib_priv_ranges *pr,
-                                              netwib_conststring str,
-                                              netwib_bool usedel)
+static netwib_err netwib_priv_ips_add_string_ip4(netwib_priv_ranges *pr,
+                                                 netwib_conststring str,
+                                                 netwib_bool usedel)
 {
   netwib_byte array[2*NETWIB_IP4_LEN];
   netwib_byte infarray[NETWIB_IPS_LEN], suparray[NETWIB_IPS_LEN];
@@ -258,9 +258,9 @@ static netwib_err netwib_priv_ips_add_str_ip4(netwib_priv_ranges *pr,
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_ips_add_str_ip6(netwib_priv_ranges *pr,
-                                              netwib_conststring str,
-                                              netwib_bool usedel)
+static netwib_err netwib_priv_ips_add_string_ip6(netwib_priv_ranges *pr,
+                                                 netwib_conststring str,
+                                                 netwib_bool usedel)
 {
   netwib_byte infarray[NETWIB_IPS_LEN], suparray[NETWIB_IPS_LEN];
   netwib_ip infip, supip;
@@ -273,7 +273,7 @@ static netwib_err netwib_priv_ips_add_str_ip6(netwib_priv_ranges *pr,
   if (pc != NULL) {
     supip.iptype = NETWIB_IPTYPE_IP6; /* for compiler warning */
     netwib_er(netwib_buf_init_mallocdefault(&buf));
-    netwib_er(netwib_buf_append_text(str, &buf));
+    netwib_er(netwib_buf_append_string(str, &buf));
     netwib_er(netwib_buf_ref_string(&buf, &pcbuf));
     pc = netwib_c_strchr(pcbuf, '-');
     *pc++ = '\0';
@@ -309,9 +309,9 @@ static netwib_err netwib_priv_ips_add_str_ip6(netwib_priv_ranges *pr,
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_ips_add_str_hns(netwib_priv_ranges *pr,
-                                              netwib_conststring hn,
-                                              netwib_bool usedel)
+static netwib_err netwib_priv_ips_add_string_hns(netwib_priv_ranges *pr,
+                                                 netwib_conststring hn,
+                                                 netwib_bool usedel)
 {
   netwib_byte array[NETWIB_IPS_LEN];
   netwib_ip ipa;
@@ -475,9 +475,9 @@ static netwib_err netwib_priv_ips_add_str_hns(netwib_priv_ranges *pr,
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_priv_ips_add_str_hn(netwib_priv_ranges *pr,
-                                             netwib_conststring str,
-                                             netwib_bool usedel)
+static netwib_err netwib_priv_ips_add_string_hn(netwib_priv_ranges *pr,
+                                                netwib_conststring str,
+                                                netwib_bool usedel)
 {
   netwib_byte infarray[NETWIB_IPS_LEN], suparray[NETWIB_IPS_LEN];
   netwib_ip infip, supip;
@@ -487,13 +487,13 @@ static netwib_err netwib_priv_ips_add_str_hn(netwib_priv_ranges *pr,
 
   pc = netwib_c_strchr(str, '=');
   if (pc == NULL) {
-    netwib_er(netwib_priv_ips_add_str_hns(pr, str, usedel));
+    netwib_er(netwib_priv_ips_add_string_hns(pr, str, usedel));
     return(NETWIB_ERR_OK);
   }
 
   supip.iptype = NETWIB_IPTYPE_IP4; /* for compiler warning */
   netwib_er(netwib_buf_init_mallocdefault(&buf));
-  netwib_er(netwib_buf_append_text(str, &buf));
+  netwib_er(netwib_buf_append_string(str, &buf));
   netwib_er(netwib_buf_ref_string(&buf, &pcbuf));
   pc = netwib_c_strchr(pcbuf, '=');
   *pc++ = '\0';
@@ -523,25 +523,25 @@ static netwib_err netwib_priv_ips_add_str_hn(netwib_priv_ranges *pr,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_priv_ips_add_str(netwib_priv_ranges *pr,
-                                   netwib_conststring str,
-                                   netwib_bool usedel)
+netwib_err netwib_priv_ips_add_string(netwib_priv_ranges *pr,
+                                      netwib_conststring str,
+                                      netwib_bool usedel)
 {
   netwib_err ret;
 
-  ret = netwib_priv_ips_add_str_all(pr, str, usedel);
+  ret = netwib_priv_ips_add_string_all(pr, str, usedel);
   if (ret == NETWIB_ERR_OK) return(NETWIB_ERR_OK);
   if (ret != NETWIB_ERR_NOTCONVERTED) return(ret);
 
-  ret = netwib_priv_ips_add_str_ip4(pr, str, usedel);
+  ret = netwib_priv_ips_add_string_ip4(pr, str, usedel);
   if (ret == NETWIB_ERR_OK) return(NETWIB_ERR_OK);
   if (ret != NETWIB_ERR_NOTCONVERTED) return(ret);
 
-  ret = netwib_priv_ips_add_str_ip6(pr, str, usedel);
+  ret = netwib_priv_ips_add_string_ip6(pr, str, usedel);
   if (ret == NETWIB_ERR_OK) return(NETWIB_ERR_OK);
   if (ret != NETWIB_ERR_NOTCONVERTED) return(ret);
 
-  ret = netwib_priv_ips_add_str_hn(pr, str, usedel);
+  ret = netwib_priv_ips_add_string_hn(pr, str, usedel);
   if (ret == NETWIB_ERR_OK) return(NETWIB_ERR_OK);
   if (ret != NETWIB_ERR_NOTCONVERTED) return(ret);
 
