@@ -415,11 +415,15 @@ static netwib_err netwib_priv_ranges_search_dichotomy(netwib_priv_constranges *p
 }
 
 /*-------------------------------------------------------------*/
+/* Warning : this function has to be called before searching for items,
+   otherwise, if memory is reallocated, the found addresses are not valid
+   anymore */
+#define NETWIB_PRIV_RANGE_ALLOC_STEP 1024
 static netwib_err netwib_priv_ranges_eventuallyrealloc(netwib_priv_ranges *pr)
 {
   if (pr->numranges*pr->rangesize + 2*NETWIB_PRIV_RANGES_MAXITEMSIZE >
       pr->ptrallocsize) {
-    pr->ptrallocsize += 1024;
+    pr->ptrallocsize += NETWIB_PRIV_RANGE_ALLOC_STEP;
     netwib_er(netwib_ptr_realloc(pr->ptrallocsize, (netwib_ptr*)&pr->ptr));
   }
 
@@ -434,7 +438,7 @@ netwib_err netwib_priv_ranges_init(netwib_priv_ranges_inittype inittype,
   pr->inittype = inittype;
   pr->itemsize = itemsize;
   pr->rangesize = 2 * itemsize;
-  pr->ptrallocsize = 1024;
+  pr->ptrallocsize = NETWIB_PRIV_RANGE_ALLOC_STEP;
   pr->numranges = 0;
   netwib_er(netwib_ptr_malloc(pr->ptrallocsize, (netwib_ptr*)&pr->ptr));
 
@@ -492,7 +496,7 @@ static netwib_err netwib_priv_ranges_add_sort(netwib_priv_ranges *pr,
     netwib_c_memcpy(foundrange, ptr, pr->itemsize);
   } else {
     /* prepend it */
-    netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+    /* note : memory has been reallocated in netwib_priv_ranges_add() */
     netwib_c_memmove(foundrange+pr->rangesize, foundrange,
                     (pr->numranges-foundindex)*pr->rangesize);
     netwib_c_memcpy(foundrange, ptr, pr->itemsize);
@@ -523,7 +527,7 @@ static netwib_err netwib_priv_ranges_add_notsort(netwib_priv_ranges *pr,
 
   /* append at end */
   pitem = (netwib_data)pr->ptr + pr->numranges * pr->rangesize;
-  netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+  /* note : memory has been reallocated in netwib_priv_ranges_add() */
   netwib_c_memcpy(pitem, ptr, pr->itemsize);
   netwib_c_memcpy(pitem+pr->itemsize, ptr, pr->itemsize);
   pr->numranges++;
@@ -536,6 +540,9 @@ netwib_err netwib_priv_ranges_add(netwib_priv_ranges *pr,
 
   netwib__debug_ranges_check("netwib_priv_ranges_add", pr);
 
+  /* always start by reallocating: see comment before eventuallyrealloc */
+  netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+
   if (pr->inittype == NETWIB_PRIV_RANGES_INITTYPE_SORTUNIQ) {
     netwib_er(netwib_priv_ranges_add_sort(pr, ptr));
   } else {
@@ -608,7 +615,7 @@ static netwib_err netwib_priv_ranges_add_range_sort(netwib_priv_ranges *pr,
   } else {
     if (inffoundindex == supfoundindex) {
       /* we need to insert one range */
-      netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+      /* note : memory has been reallocated in netwib_priv_ranges_add_range()*/
       netwib_c_memmove(inffoundrange+pr->rangesize, inffoundrange,
                       (pr->numranges-inffoundindex)*pr->rangesize);
       netwib_c_memcpy(inffoundrange, ptrinf, pr->itemsize);
@@ -650,7 +657,7 @@ static netwib_err netwib_priv_ranges_add_range_notsort(netwib_priv_ranges *pr,
 
   /* append at end */
   pitem = (netwib_data)pr->ptr + pr->numranges * pr->rangesize;
-  netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+  /* note : memory has been reallocated in netwib_priv_ranges_add_range()*/
   netwib_c_memcpy(pitem, ptrinf, pr->itemsize);
   netwib_c_memcpy(pitem+pr->itemsize, ptrsup, pr->itemsize);
   pr->numranges++;
@@ -664,6 +671,9 @@ netwib_err netwib_priv_ranges_add_range(netwib_priv_ranges *pr,
 
   netwib__debug_ranges_check("netwib_priv_ranges_add_range", pr);
 
+  /* always start by reallocating: see comment before eventuallyrealloc */
+  netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+
   if (pr->inittype == NETWIB_PRIV_RANGES_INITTYPE_SORTUNIQ) {
     netwib_er(netwib_priv_ranges_add_range_sort(pr, ptrinf, ptrsup));
   } else {
@@ -722,7 +732,7 @@ static netwib_err netwib_priv_ranges_del_item(netwib_priv_ranges *pr,
     return(NETWIB_ERR_OK);
   } else {
     /* cut the range in two */
-    netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+    /* note : memory has been reallocated in netwib_priv_ranges_del() */
     netwib_c_memmove(itemrange+pr->rangesize, itemrange,
                      (pr->numranges-itemindex)*pr->rangesize);
     netwib_c_memcpy(itemrange, itemrange+pr->rangesize, pr->itemsize);
@@ -782,6 +792,9 @@ netwib_err netwib_priv_ranges_del(netwib_priv_ranges *pr,
 
   netwib__debug_ranges_check("netwib_priv_ranges_del", pr);
 
+  /* always start by reallocating: see comment before eventuallyrealloc */
+  netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+
   if (pr->inittype == NETWIB_PRIV_RANGES_INITTYPE_SORTUNIQ) {
     netwib_er(netwib_priv_ranges_del_sort(pr, ptr));
   } else {
@@ -829,7 +842,7 @@ static netwib_err netwib_priv_ranges_del_items(netwib_priv_ranges *pr,
   if (infinthisrange && supinthisrange) {
     if (iteminfindex == itemsupindex) {
       /* we need to insert one range */
-      netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+      /* note : memory has been reallocated in netwib_priv_ranges_del_range()*/
       netwib_c_memmove(iteminfrange+pr->rangesize+pr->itemsize,
                        iteminfrange+pr->itemsize,
                        (pr->numranges-iteminfindex)*pr->rangesize);
@@ -962,6 +975,9 @@ netwib_err netwib_priv_ranges_del_range(netwib_priv_ranges *pr,
 
   netwib__debug_ranges_check("netwib_priv_ranges_del_range", pr);
 
+  /* always start by reallocating: see comment before eventuallyrealloc */
+  netwib_er(netwib_priv_ranges_eventuallyrealloc(pr));
+
   netwib_er(netwib_priv_ranges_item_cmp(pr, ptrinf, ptrsup, &cmp));
   if (cmp == NETWIB_CMP_GT) {
     return(NETWIB_ERR_PAINVALIDRANGE);
