@@ -341,11 +341,11 @@ netwib_err netwib_priv_sa_recv(int fd,
   /* an error occurred */
 #if defined NETWIBDEF_SYSNAME_Unix
   if (readsize == -1) {
-    if (errno == EAGAIN) {
+    if (errno == EAGAIN || errno == EINTR) {
       /* nothing was available */
       errno = 0;
       return(NETWIB_ERR_DATANOTAVAIL);
-    } else if (errno == EBADF) {
+    } else if (errno == EBADF || errno == ECONNRESET) {
       /* reached end */
       errno = 0;
       return(NETWIB_ERR_DATAEND);
@@ -405,11 +405,11 @@ netwib_err netwib_priv_sa_recvfrom(int fd,
   /* an error occurred */
 #if defined NETWIBDEF_SYSNAME_Unix
   if (readsize == -1) {
-    if (errno == EAGAIN) {
+    if (errno == EAGAIN || errno == EINTR) {
       /* nothing was available */
       errno = 0;
       return(NETWIB_ERR_DATANOTAVAIL);
-    } else if (errno == EBADF) {
+    } else if (errno == EBADF || errno == ECONNRESET) {
       /* reached end */
       errno = 0;
       return(NETWIB_ERR_DATAEND);
@@ -427,7 +427,7 @@ netwib_err netwib_priv_sa_recvfrom(int fd,
     case WSAEWOULDBLOCK :
       return(NETWIB_ERR_DATANOTAVAIL);
     default :
-      return(NETWIB_ERR_FURECV);
+      return(NETWIB_ERR_FURECVFROM);
     }
   }
 #else
