@@ -1,24 +1,20 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2008 Laurent Constantin
-                                  -----
-
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwib.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
   This file is part of Netwib.
 
-  Netwib is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwib is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwib is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -142,7 +138,7 @@ static netwib_err netwib_pkt_decode_nullhdr(netwib_constbuf *ppkt,
                                              (pnullhdr->type>>24));
     }
     /* under BSD, this field can also contain AF_xyz */
-    switch(pnullhdr->type) {
+    switch((int)pnullhdr->type) {
       case AF_INET :
         pnullhdr->type = NETWIB_ETHERHDRTYPE_IP4;
         break;
@@ -195,7 +191,7 @@ static netwib_err netwib_pkt_decode_loophdr(netwib_constbuf *ppkt,
     data = netwib__buf_ref_data_ptr(ppkt);
     netwib__data_decode_uint32t(data, ploophdr->type, netwib_etherhdrtype);
     /* under BSD, this field can contain AF_xyz */
-    switch(ploophdr->type) {
+    switch((int)ploophdr->type) {
       case AF_INET :
         ploophdr->type = NETWIB_ETHERHDRTYPE_IP4;
         break;
