@@ -1,24 +1,20 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2008 Laurent Constantin
-                                  -----
-
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwib.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
   This file is part of Netwib.
 
-  Netwib is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwib is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwib is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -94,6 +90,6 @@ netwib_err netwib_decodetype_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_ext_string("Your choice", &msg));
   netwib_er(netwib_uint32_init_kbd(&msg, 0, i-1, defaultchoice, &choice));
 
-  if (pdecodetype != NULL) *pdecodetype = (netwib_decodetype)choice;
+  if (pdecodetype != NULL) *pdecodetype = array[choice];
   return(NETWIB_ERR_OK);
 }
