@@ -1,27 +1,20 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2006 Laurent Constantin
-                                  -----
-
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
-  [my current email address is on the web servers]
-
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwib.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
   This file is part of Netwib.
 
-  Netwib is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwib is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwib is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -40,11 +33,6 @@
  #include "debug/thread.c"
 #endif
 
-/*-------------------------------------------------------------*/
-#if NETWIB_DEBUG_SIGHDL_NEEDED==1
- #include "debug/sighdl.c"
-#endif
-
 /*-------------------------------------------------------------*/
 #if NETWIB_DEBUG_GLOVARS_NEEDED==1
  #include "debug/glovars.c"
@@ -71,7 +59,15 @@
 #endif
 
 /*-------------------------------------------------------------*/
-static netwib_err netwib_unused_sys_debug(void)
+#if NETWIB_DEBUG_SIGHDL_NEEDED==1
+ #include "debug/sighdl.c"
+#endif
+
+/*-------------------------------------------------------------*/
+/* we need this function otherwise gcc refuses to compile this C file
+   because it does not contain any code */
+netwib_err netwib_unused_sys_debug(void);
+netwib_err netwib_unused_sys_debug(void)
 {
   netwib_unused_sys_debug();
   return(NETWIB_ERR_OK);
