@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -347,21 +347,21 @@ netwib_err netwib_debug_backtrace_array(netwib_uint32 btmaxsize,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_debug_backtrace_str(netwib_string *pstringout)
+netwib_err netwib_debug_backtrace_string(netwib_string *pstringout)
 {
   void *bt[NETWIB_DEBUG_BACKTRACE_MAXSIZE];
   netwib_uint32 btsize, i;
 
   netwib_er(netwib_debug_backtrace_array(NETWIB_DEBUG_BACKTRACE_MAXSIZE,
                                          bt, &btsize));
-  netwib_er(netwib_debug_str_init(pstringout));
+  netwib_er(netwib_debug_string_init(pstringout));
   if (btsize == 0) {
-    netwib_er(netwib_debug_str_append_text("empty", pstringout));
+    netwib_er(netwib_debug_string_append_string("empty", pstringout));
   } else {
     for (i = 0; i < btsize - 1; i++) {
-      netwib_er(netwib_debug_str_append_fmt(pstringout, "%p,", bt[i]));
+      netwib_er(netwib_debug_string_append_fmt(pstringout, "%p,", bt[i]));
     }
-    netwib_er(netwib_debug_str_append_fmt(pstringout, "%p", bt[btsize - 1]));
+    netwib_er(netwib_debug_string_append_fmt(pstringout, "%p", bt[btsize - 1]));
   }
 
   return(NETWIB_ERR_OK);
@@ -372,10 +372,10 @@ netwib_err netwib_debug_backtrace_disp(void)
 {
   netwib_string str;
 
-  netwib_er(netwib_debug_backtrace_str(&str));
-  netwib_er(netwib_debug_str_append_text("\n", &str));
-  netwib_er(netwib_debug_disp_text(str));
-  netwib_er(netwib_debug_str_close(&str));
+  netwib_er(netwib_debug_backtrace_string(&str));
+  netwib_er(netwib_debug_string_append_string("\n", &str));
+  netwib_er(netwib_debug_disp_string(str));
+  netwib_er(netwib_debug_string_close(&str));
 
   return(NETWIB_ERR_OK);
 }
