@@ -1,6 +1,6 @@
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_debug_disp_text(netwib_conststring msg);
+netwib_err netwib_debug_disp_string(netwib_conststring msg);
 netwib_err netwib_debug_disp_fmt(netwib_conststring fmt,
                                  ...);
 
