@@ -1,24 +1,20 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2008 Laurent Constantin
-                                  -----
-
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwib.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
   This file is part of Netwib.
 
-  Netwib is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwib is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwib is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -38,6 +34,9 @@ netwib_err netwib_global_ctl_set(netwib_global_ctltype type,
     case NETWIB_GLOBAL_CTLTYPE_CONF_UPDATE:
       netwib_er(netwib_priv_conf_update());
       break;
+    case NETWIB_GLOBAL_CTLTYPE_DEBUG_CTRLC_PRESSED:
+      return(NETWIB_ERR_PAINVALIDTYPE);
+      break;
     default :
       return(NETWIB_ERR_PAINVALIDTYPE);
       ui = ui;
@@ -58,6 +57,9 @@ netwib_err netwib_global_ctl_get(netwib_global_ctltype type,
     case NETWIB_GLOBAL_CTLTYPE_CONF_UPDATE:
       return(NETWIB_ERR_PAINVALIDTYPE);
       break;
+    case NETWIB_GLOBAL_CTLTYPE_DEBUG_CTRLC_PRESSED:
+      *pui = (netwib_uint32)netwib_priv_glovars.debug_ctrlc_pressed;
+      break;
     default :
       return(NETWIB_ERR_PAINVALIDTYPE);
       pui = pui;
