@@ -1,50 +1,21 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
-typedef struct {
-  int readfd;
-  int writefd;
-  int pid;
-  netwib_bool killonclose;
-  netwib_bool *pexitednormally;
-  netwib_uint32 *preturnedvalue;
-} netwib_priv_io_exec;
+#define NETWIBDEF_IOSHELL_SUPPORTED 0
+#if defined NETWIBDEF_SYSNAME_Linux
+ #if NETWIBDEF_HAVEINCL_PTY == 1
+  #if NETWIBDEF_LIBUTILINSTALLED == 1
+   #undef NETWIBDEF_IOSHELL_SUPPORTED
+   #define NETWIBDEF_IOSHELL_SUPPORTED 1
+  #endif
+ #endif
+#endif
 
 /*-------------------------------------------------------------*/
-#if NETWIBDEF_LIBPTHREADFROMMIT == 0
-static netwib_err netwib_priv_io_exec_close_descriptors(netwib_uint32 excepted)
-{
-  netwib_uint32 themax, i;
-
- #if NETWIBDEF_HAVEFUNC_GETRLIMIT==1
-  {
-    struct rlimit lim;
-    int reti;
-    reti = getrlimit(RLIMIT_NOFILE, &lim);
-    if (reti == -1) {
-      return(NETWIB_ERR_FUGETRLIMIT);
-    }
-    themax = lim.rlim_cur;
-  }
- #elif NETWIBDEF_HAVEFUNC_SYSCONF==1
-  themax = sysconf(_SC_OPEN_MAX);
- #else
-  themax = OPEN_MAX;
- #endif
-
-  /* we could use "fcntl(fd, F_SETFD, FD_CLOEXEC);", but we have to check
-     if fd is open. So, I choose to close everything. */
-  for (i = 3 ; i < excepted; i++) {
-    /*ignore*/close(i);
-  }
-  for (i = excepted+1 ; i < themax; i++) {
-    /*ignore*/close(i);
-  }
-
-  return(NETWIB_ERR_OK);
-}
-#endif
+typedef struct {
+  netwib_priv_io_execcommon common;
+} netwib_priv_io_exec;
 
 /*-------------------------------------------------------------*/
 static netwib_err netwib_priv_io_exec_init_child(netwib_conststring filename,
@@ -68,7 +39,8 @@ static netwib_err netwib_priv_io_exec_init_child(netwib_conststring filename,
   /* child becomes session leader : like this, a kill will kill
      every sub-child.
   */
-  /*ignore*/setsid();
+  reti = setsid();
+  if (reti == -1) return(NETWIB_ERR_FUSETSID);
 
   /* open /dev/null */
   devnull = open("/dev/null", O_RDWR);
@@ -98,25 +70,9 @@ static netwib_err netwib_priv_io_exec_init_child(netwib_conststring filename,
   reti = dup2(devnull, STDERR_FILENO);
   if (reti == -1) return(NETWIB_ERR_FUDUP2);
 
-  /* prepare our trick to check if exec succeeded */
-  reti = close(checkexec[0]);
-  if (reti == -1) return(NETWIB_ERR_FUCLOSE);
-  reti = fcntl(checkexec[1], F_SETFD, FD_CLOEXEC);
-  if (reti == -1) return(NETWIB_ERR_FUFCNTL);
-
-  /* close unneeded file descriptors */
-#if NETWIBDEF_LIBPTHREADFROMMIT == 0
-  /* except for MIT POSIX threads, because a private fd is used, and we
-     don't know which one is */
-  netwib_er(netwib_priv_io_exec_close_descriptors(checkexec[1]));
-#endif
-
   /* exec */
-  reti = execve(filename, argv, NULL);
-  if (reti < 0) return(NETWIB_ERR_LOCANTEXEC);
-
-  /* should not be reached */
-  return(NETWIB_ERR_LOINTERNALERROR);
+  netwib_er(netwib_priv_io_execcommon_launch_child2(filename, argv, NULL, checkexec));
+  return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
@@ -126,70 +82,20 @@ static netwib_err netwib_priv_io_exec_init3(netwib_string filename,
                                             int fathertochild[2],
                                             int *ppid)
 {
-  netwib_err ret, retchild;
+  netwib_err ret;
   int checkexec[2];
-  int pid;
-  int reti;
 
-  /* this pipe is used to check if exec worked */
-  reti = pipe(checkexec);
-  if (reti == -1) return(NETWIB_ERR_FUPIPE);
+  netwib_er(netwib_priv_io_execcommon_launch_father1(&checkexec, ppid));
 
-  /* try to launch child */
-  pid = fork();
-  if (pid == -1) {
-    close(checkexec[0]);
-    close(checkexec[1]);
-    return(NETWIB_ERR_FUFORK);
-  }
-
-  if (pid == 0) {
+  if (*ppid == 0) {
     /* child */
     ret = netwib_priv_io_exec_init_child(filename, argv,
                                          childtofather, fathertochild,
                                          checkexec);
-    /* error number is written to checkexec pipe */
-    /*ignore*/netwib_priv_fdpipe_write_uint32(checkexec[1], ret);
-    _exit(NETWIB_ERR_DATAEND);
-    return(NETWIB_ERR_LOINTERNALERROR);
-    /* never reached */
+    netwib_er(netwib_priv_io_execcommon_launch_child1(checkexec, ret));
   }
 
-  /* wait to ensure exec is ok */
-  reti = close(checkexec[1]);
-  if (reti == -1) return(NETWIB_ERR_FUCLOSE);
-#if NETWIBDEF_LIBPTHREADFROMMIT == 1
-  /* read implementation in MIT POSIX threads does not detect the close.
-     So, we first wait for one second */
- {
-   netwib_time t;
-   netwib_bool event;
-   netwib_er(netwib_time_init_now(&t));
-   netwib_er(netwib_time_plus_sec(&t, 1));
-   netwib_er(netwib_priv_fd_wait(checkexec[0], NETWIB_IO_WAYTYPE_READ,
-                                 &t, &event));
-   if (event) {
-     ret = netwib_priv_fd_read_uint32(checkexec[0], (netwib_uint32*)&retchild);
-   } else {
-     ret = NETWIB_ERR_DATAEND;
-   }
- }
-#else
-  ret = netwib_priv_fd_read_uint32(checkexec[0], (netwib_uint32*)&retchild);
-#endif
-  close(checkexec[0]);
-  if (ret == NETWIB_ERR_OK) {
-    if (retchild == NETWIB_ERR_OK) {
-      return(NETWIB_ERR_LOERROROKKO);
-    } else {
-      return(retchild);
-    }
-  } else if (ret != NETWIB_ERR_DATAEND) {
-    return(ret);
-  }
-
-  /* store information */
-  *ppid = pid;
+  netwib_er(netwib_priv_io_execcommon_launch_father2(checkexec));
   return(NETWIB_ERR_OK);
 }
 
@@ -302,7 +208,7 @@ static netwib_err netwib_priv_io_exec_init(netwib_constbuf *pbufcommand,
                                            netwib_priv_io_exec *ptr)
 {
   netwib_string filename, *argv;
-  netwib_err ret;
+  netwib_err ret=NETWIB_ERR_OK;
   int pid=0, readfd=0, writefd=0;
 
   /* try to launch child */
@@ -315,14 +221,7 @@ static netwib_err netwib_priv_io_exec_init(netwib_constbuf *pbufcommand,
   }
 
   /* store information */
-  ptr->readfd = readfd;
-  ptr->writefd = writefd;
-  ptr->pid = pid;
-  ptr->killonclose = killonclose;
-  ptr->pexitednormally = pexitednormally;
-  ptr->preturnedvalue = preturnedvalue;
-  *preadinitialized = (readfd==-1)?NETWIB_FALSE:NETWIB_TRUE;
-  *pwriteinitialized = (writefd==-1)?NETWIB_FALSE:NETWIB_TRUE;
+  netwib_er(netwib_priv_io_execcommon_init(readfd, writefd, pid, killonclose, pexitednormally, preturnedvalue, preadinitialized, pwriteinitialized, &ptr->common));
 
   return(NETWIB_ERR_OK);
 }
@@ -330,60 +229,7 @@ static netwib_err netwib_priv_io_exec_init(netwib_constbuf *pbufcommand,
 /*-------------------------------------------------------------*/
 static netwib_err netwib_priv_io_exec_close(netwib_priv_io_exec *ptr)
 {
-  int reti, status;
-
-  if (ptr->killonclose) {
-    /* smooth then violent kill of the child */
-#if NETWIBDEF_LIBPTHREADFROMMIT == 1
-    /* waitpid implementation in MIT POSIX threads does not support WNOHANG */
-    /* note we send signal to the group */
-    /* ignore */ kill( - ptr->pid, SIGTERM);
-    netwib_er(netwib_priv_pause());
-    /* ignore */ kill( - ptr->pid, SIGKILL);
-    reti = waitpid(ptr->pid, &status, 0);
-#else
-    reti = waitpid(ptr->pid, &status, WNOHANG);
-    if (reti == 0) {
-      /* note we send signal to the group */
-      /* ignore */ kill( - ptr->pid, SIGTERM);
-      netwib_er(netwib_priv_pause());
-      reti = waitpid(ptr->pid, &status, WNOHANG);
-      if (reti == 0) {
-        /* ignore */ kill( - ptr->pid, SIGKILL);
-        reti = waitpid(ptr->pid, &status, 0);
-      }
-    }
-#endif
-  } else {
-    reti = waitpid(ptr->pid, &status, 0);
-  }
-  if (reti != ptr->pid) {
-    return(NETWIB_ERR_FUWAITPID);
-  }
-
-  if (WIFEXITED(status)) {
-    if (ptr->pexitednormally != NULL) {
-      *(ptr->pexitednormally) = NETWIB_TRUE;
-    }
-    if (ptr->preturnedvalue != NULL) {
-      *(ptr->preturnedvalue) = WEXITSTATUS(status);
-    }
-  } else {
-    if (ptr->pexitednormally != NULL) {
-      *(ptr->pexitednormally) = NETWIB_FALSE;
-    }
-  }
-
-  /* close descriptors */
-  if (ptr->readfd != -1) {
-    reti = close(ptr->readfd);
-    if (reti == -1) return(NETWIB_ERR_FUCLOSE);
-  }
-  if (ptr->writefd != -1) {
-    reti = close(ptr->writefd);
-    if (reti == -1) return(NETWIB_ERR_FUCLOSE);
-  }
-
+  netwib_er(netwib_priv_io_execcommon_close(&ptr->common));
   return(NETWIB_ERR_OK);
 }
 
@@ -392,7 +238,8 @@ static netwib_err netwib_priv_io_exec_read(netwib_io *pio,
                                            netwib_buf *pbuf)
 {
   netwib_priv_io_exec *ptr = (netwib_priv_io_exec *)pio->pcommon;
-  return(netwib_priv_fd_read(ptr->readfd, pbuf));
+  netwib_er(netwib_priv_io_execcommon_read(&ptr->common, pbuf));
+  return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
@@ -400,7 +247,8 @@ static netwib_err netwib_priv_io_exec_write(netwib_io *pio,
                                             netwib_constbuf *pbuf)
 {
   netwib_priv_io_exec *ptr = (netwib_priv_io_exec *)pio->pcommon;
-  return(netwib_priv_fdpipe_write(ptr->writefd, pbuf));
+  netwib_er(netwib_priv_io_execcommon_write(&ptr->common, pbuf));
+  return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
@@ -410,22 +258,7 @@ static netwib_err netwib_priv_io_exec_wait(netwib_io *pio,
                                            netwib_bool *pevent)
 {
   netwib_priv_io_exec *ptr = (netwib_priv_io_exec *)pio->pcommon;
-
-  switch (way) {
-    case NETWIB_IO_WAYTYPE_READ :
-      netwib_er(netwib_priv_fd_wait(ptr->readfd, way, pabstime, pevent));
-      break;
-    case NETWIB_IO_WAYTYPE_WRITE :
-      netwib_er(netwib_priv_fd_wait(ptr->writefd, way, pabstime, pevent));
-      break;
-    case NETWIB_IO_WAYTYPE_RDWR :
-    case NETWIB_IO_WAYTYPE_SUPPORTED :
-      return(NETWIB_ERR_PLEASECONSTRUCT);
-      break;
-    default :
-      return(NETWIB_ERR_PAINVALIDTYPE);
-  }
-
+  netwib_er(netwib_priv_io_execcommon_wait(&ptr->common, way, pabstime, pevent));
   return(NETWIB_ERR_OK);
 }
 
@@ -437,29 +270,11 @@ static netwib_err netwib_priv_io_exec_ctl_set(netwib_io *pio,
                                               netwib_uint32 ui)
 {
   netwib_priv_io_exec *ptr = (netwib_priv_io_exec *)pio->pcommon;
-  int reti;
-
-  switch(type) {
-    case NETWIB_IO_CTLTYPE_RES:
-      return(NETWIB_ERR_PAINVALIDTYPE);
-      break;
-    case NETWIB_IO_CTLTYPE_END:
-      if (way != NETWIB_IO_WAYTYPE_WRITE) return(NETWIB_ERR_PAINVALIDTYPE);
-      if (ptr->writefd != -1) {
-        reti = close(ptr->writefd);
-        if (reti == -1) return(NETWIB_ERR_FUCLOSE);
-        ptr->writefd = -1;
-      }
-      pio->wr.supported = NETWIB_FALSE;
-      return(NETWIB_ERR_OK);
-      break;
-    default:
-      return(NETWIB_ERR_PLEASETRYNEXT);
+  netwib_er(netwib_priv_io_execcommon_ctl_set(&ptr->common, way, type, p, ui));
+  if (type == NETWIB_IO_CTLTYPE_END) {
+    pio->wr.supported = NETWIB_FALSE;
   }
-
-  p = p; /* for compiler warning */
-  ui = ui; /* for compiler warning */
-  return(NETWIB_ERR_PLEASETRYNEXT);
+  return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
@@ -469,20 +284,16 @@ static netwib_err netwib_priv_io_exec_ctl_get(netwib_io *pio,
                                               netwib_ptr p,
                                               netwib_uint32 *pui)
 {
+  netwib_priv_io_exec *ptr = (netwib_priv_io_exec *)pio->pcommon;
 
   switch(type) {
-    case NETWIB_IO_CTLTYPE_RES:
-      if (pui != NULL) *pui = NETWIB_IO_RESTYPE_EXEC;
-      return(NETWIB_ERR_OK);
-    case NETWIB_IO_CTLTYPE_END:
-      return(NETWIB_ERR_PAINVALIDTYPE);
-    default:
-      return(NETWIB_ERR_PLEASETRYNEXT);
+  case NETWIB_IO_CTLTYPE_RES:
+    if (pui != NULL) *pui = NETWIB_IO_RESTYPE_EXEC;
+    return(NETWIB_ERR_OK);
+  default:
+    return(netwib_priv_io_execcommon_ctl_get(&ptr->common, way, type, p, pui));
   }
 
-  pio = pio; /* for compiler warning */
-  way = way; /* for compiler warning */
-  p = p; /* for compiler warning */
   return(NETWIB_ERR_PLEASETRYNEXT);
 }
 
@@ -509,9 +320,9 @@ netwib_err netwib_io_init_exec(netwib_constbuf *pbufcommand,
   netwib_err ret;
 
   netwib_er(netwib_ptr_malloc(sizeof(netwib_priv_io_exec), &pcommon));
-  ret = netwib_priv_io_exec_init(pbufcommand, providedway, killonclose,
-                                 pexitednormally, preturnedvalue,
-                                 &rdsup, &wrsup,
+  ret = netwib_priv_io_exec_init(pbufcommand, providedway,
+                                 killonclose, pexitednormally,
+                                 preturnedvalue, &rdsup, &wrsup,
                                  (netwib_priv_io_exec *)pcommon);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_ptr_free(&pcommon));
