@@ -21,13 +21,11 @@ netwib_err netwib_priv_dll_init(void)
   }
 
   /* init snmp */
- #if NETWIBDEF_HAVEFUNC_WINDOWS_SNMP == 1
   ret = netwib_priv_dll_snmp_init(&netwib_global_dll_snmp);
   if (ret != NETWIB_ERR_OK) {
     /* ensure it is not loaded */
     netwib_global_dll_snmp.isloaded = NETWIB_FALSE;
   }
- #endif
 
   /* init kernel32 */
   ret = netwib_priv_dll_kernel32_init(&netwib_global_dll_kernel32);
@@ -86,11 +84,9 @@ netwib_err netwib_priv_dll_close(void)
   ret = netwib_priv_dll_kernel32_close(&netwib_global_dll_kernel32);
   if (ret != NETWIB_ERR_OK)
     retret = ret;
- #if NETWIBDEF_HAVEFUNC_WINDOWS_SNMP == 1
   ret = netwib_priv_dll_snmp_close(&netwib_global_dll_snmp);
   if (ret != NETWIB_ERR_OK)
     retret = ret;
- #endif
   ret = netwib_priv_dll_winsock2_close(&netwib_global_dll_winsock2);
   if (ret != NETWIB_ERR_OK)
     retret = ret;
