@@ -686,7 +686,7 @@ netwib_err netwib_priv_err_append_err(netwib_err error,
 
   /* GetLastError */
 #if defined NETWIBDEF_SYSNAME_Unix
-  vargetlasterror = 0;
+  vargetlasterror = vargetlasterror;
 #elif defined NETWIBDEF_SYSNAME_Windows
   if (vargetlasterror) {
     LPVOID lpMsgBuf;
