@@ -9,8 +9,8 @@ typedef enum {
 } netwib_priv_notifytype;
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_priv_notify_text(netwib_priv_notifytype type,
-                                   netwib_conststring msg);
+netwib_err netwib_priv_notify_string(netwib_priv_notifytype type,
+                                     netwib_conststring msg);
 netwib_err netwib_priv_notify_fmt(netwib_priv_notifytype type,
                                   netwib_conststring fmt,
                                   ...);
