@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -287,7 +284,10 @@ static netwib_err netwox_brute_core_multithread(netwib_ring_index *pringloginind
     /* check if one thread exited */
     ret = netwib_threadlist_wait(pthreadlist, newthreadlaunched?NETWIB_TIME_ZERO:NETWIB_TIME_INFINITE, &event, &threadid, &ret2, (netwib_ptr*)&pbtm);
     if (ret != NETWIB_ERR_OK) {
-      if (ret == NETWIB_ERR_DATANOTAVAIL) continue;
+      if (ret == NETWIB_ERR_DATANOTAVAIL) {
+        ret = NETWIB_ERR_OK;
+        continue;
+      }
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
       break;
     }
