@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -356,15 +353,17 @@ netwib_err netwox_dnspktex_answer(netwib_constbuf *pquestion,
   netwox_dnshdr dnsheader;
   netwox_dnsrr_type type;
   netwox_dnsrr_class rclass;
+  netwib_err ret;
 
   /* use an array, to not have to bother with freeing memory */
   netwib_er(netwib_buf_init_ext_arraysizeofempty(namearray, &name));
 
-  /* check its a question */
+  /* check if it's a question */
   netwib_er(netwib_bufpool_initdefault(&pbufpool));
-  netwib_er(netwox_pkt_decode_dns_question(pbufpool, pquestion, &dnsheader,
-                                           &name, &type, &rclass));
+  ret = netwox_pkt_decode_dns_question(pbufpool, pquestion, &dnsheader,
+                                       &name, &type, &rclass);
   netwib_er(netwib_bufpool_close(&pbufpool));
+  netwib_er(ret);
 
   /* reject unsupported opcodes or classes */
   if (dnsheader.opcode != NETWOX_DNSHDR_OPCODE_QUERY ||
