@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -353,6 +350,7 @@ netwib_err netwox_ftpclient_file_put(netwox_ftpclient *pftpclient,
     netwib__buf_reinit(pbuf);
     ret = netwib_io_read(pfileio, pbuf);
     if (ret == NETWIB_ERR_DATANOTAVAIL) {
+      ret = NETWIB_ERR_OK;
       continue;
     } else if (ret != NETWIB_ERR_OK) {
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
@@ -415,6 +413,7 @@ netwib_err netwox_ftpclient_file_get_io(netwox_ftpclient *pftpclient,
     netwib__buf_reinit(pbuf);
     ret = netwib_io_read(pdataio, pbuf);
     if (ret == NETWIB_ERR_DATANOTAVAIL) {
+      ret = NETWIB_ERR_OK;
       continue;
     } else if (ret != NETWIB_ERR_OK) {
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
@@ -690,6 +689,7 @@ netwib_err netwox_ftpclient_dir_ls(netwox_ftpclient *pftpclient,
     netwib__buf_reinit(pbuf);
     ret = netwib_io_read(plineio, pbuf);
     if (ret == NETWIB_ERR_DATANOTAVAIL) {
+      ret = NETWIB_ERR_OK;
       continue;
     } else if (ret != NETWIB_ERR_OK) {
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
@@ -924,12 +924,12 @@ static netwib_err netwox_ftpclient_dirrec_rmdir2(netwox_ftpclient *pftpclient)
       ret = netwox_ftpclient_file_delete(pftpclient, &pdirlist->name);
       break;
     case NETWIB_PATHSTAT_TYPE_DIR :
-      netwib_er(netwib_fmt_display("Entering %{buf}\n", &pdirlist->name));
+      netwib_er(netwib_fmt_display("Entering directory %{buf}\n", &pdirlist->name));
       ret = netwox_ftpclient_dir_cd(pftpclient, &pdirlist->name);
       if (ret == NETWIB_ERR_OK) {
         ret = netwox_ftpclient_dirrec_rmdir2(pftpclient);
         if (ret == NETWIB_ERR_OK) {
-          netwib_er(netwib_fmt_display("Leaving %{buf}\n", &pdirlist->name));
+          netwib_er(netwib_fmt_display("Leaving directory %{buf}\n", &pdirlist->name));
           netwib_er(netwib_buf_init_ext_string("..", &dotdot));
           ret = netwox_ftpclient_dir_cd(pftpclient, &dotdot);
           if (ret == NETWIB_ERR_OK) {
@@ -958,24 +958,32 @@ static netwib_err netwox_ftpclient_dirrec_rmdir2(netwox_ftpclient *pftpclient)
 netwib_err netwox_ftpclient_dirrec_rmdir(netwox_ftpclient *pftpclient,
                                          netwib_constbuf *pdirname)
 {
-  netwib_buf dotdot;
+  netwib_buf dotdot, lastdir;
+  netwib_string name;
   netwib_err ret;
 
   /* go in remote dir */
+  netwib_er(netwib_fmt_display("Entering directory %{buf}\n", pdirname));
   netwib_er(netwox_ftpclient_dir_cd(pftpclient, pdirname));
 
   /* call recursive function */
   netwib_er(netwox_ftpclient_dirrec_rmdir2(pftpclient));
 
   /* try to remove directory. "try" because / or . cause problems */
-  netwib_er(netwib_fmt_display("Deleting directory %{buf}\n", pdirname));
-  netwib_er(netwib_buf_init_ext_string("..", &dotdot));
-  ret = netwox_ftpclient_dir_cd(pftpclient, &dotdot);
-  if (ret == NETWIB_ERR_OK) {
-    ret = netwox_ftpclient_dir_rmdir(pftpclient, pdirname);
-  }
-  if (ret != NETWIB_ERR_OK) {
-    netwib_er(netwib_fmt_display("Directory not deleted.\n"));
+  netwib_er(netwib_constbuf_ref_string(pdirname, &name));
+  if (netwib_c_strcmp(name, ".") && netwib_c_strcmp(name, "/")) {
+    netwib_er(netwib_fmt_display("Deleting directory %{buf}\n", pdirname));
+    netwib_er(netwib_buf_init_ext_string("..", &dotdot));
+    ret = netwox_ftpclient_dir_cd(pftpclient, &dotdot);
+    if (ret == NETWIB_ERR_OK) {
+      netwib_er(netwib_buf_init_mallocdefault(&lastdir));
+      netwib_er(netwib_path_decode_child(pdirname, &lastdir));
+      ret = netwox_ftpclient_dir_rmdir(pftpclient, &lastdir);
+      netwib_er(netwib_buf_close(&lastdir));
+    }
+    if (ret != NETWIB_ERR_OK) {
+      netwib_er(netwib_fmt_display("Directory not deleted.\n"));
+    }
   }
 
   return(NETWIB_ERR_OK);
