@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -54,6 +51,7 @@ netwib_err netwox_io_kbd_loop(netwib_io *pio,
 
   /* main loop */
   while (NETWIB_TRUE) {
+    netwib__debug_ctrlc_pressed_break();
     /* wait */
     netwib_er(netwib_wait_wait2(pnetwait, pkbdwait, NETWIB_TIME_INFINITE,
                                 &netevent, &kbdevent));
@@ -62,6 +60,7 @@ netwib_err netwox_io_kbd_loop(netwib_io *pio,
       netwib__buf_reinit(&rawbuf);
       ret = netwib_io_read(pio, &rawbuf);
       if (ret == NETWIB_ERR_DATANOTAVAIL) {
+        ret = NETWIB_ERR_OK;
         /* continue */
       } else if (ret == NETWIB_ERR_DATAEND) {
         ret = NETWIB_ERR_OK;
@@ -76,6 +75,7 @@ netwib_err netwox_io_kbd_loop(netwib_io *pio,
       netwib__buf_reinit(&rawbuf);
       ret = netwib_io_read(pkbdio, &rawbuf);
       if (ret == NETWIB_ERR_DATANOTAVAIL) {
+        ret = NETWIB_ERR_OK;
         /* continue */
       } else if (ret == NETWIB_ERR_DATAEND) {
         ret = NETWIB_ERR_OK;
@@ -130,9 +130,13 @@ netwib_err netwox_io_showecho(netwib_io *pio,
 
   /* main loop */
   while (NETWIB_TRUE) {
+    netwib__debug_ctrlc_pressed_break();
     if (maxwaitms != 0) {
       ret = netwib_io_wait_read(pio, &abstime, &event);
-      if (ret != NETWIB_ERR_OK) {
+      if (ret == NETWIB_ERR_DATAEND) {
+        ret = NETWIB_ERR_OK;
+        break;
+      } else if (ret != NETWIB_ERR_OK) {
         break;
       }
       if (!event) {
@@ -144,6 +148,7 @@ netwib_err netwox_io_showecho(netwib_io *pio,
     netwib__buf_reinit(&buf);
     ret = netwib_io_read(pio, &buf);
     if (ret == NETWIB_ERR_DATANOTAVAIL) {
+      ret = NETWIB_ERR_OK;
       /* continue */
     } else if (ret == NETWIB_ERR_DATAEND) {
       ret = NETWIB_ERR_OK;
