@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -62,6 +59,7 @@ static netwib_err netwox_remadmtcp_io_read(netwox_remadmtcp_io *pbio)
     } else if (ret != NETWIB_ERR_DATANOTAVAIL) {
       return(ret);
     }
+    ret = NETWIB_ERR_OK;
   }
 
   return(NETWIB_ERR_OK);
@@ -198,7 +196,10 @@ static netwib_err netwox_remadmtcp_io_write_io(netwib_bufpool *pbufpool,
     netwib__buf_reinit(pbuf);
     ret = netwib_io_read(pio, pbuf);
     if (ret != NETWIB_ERR_OK) {
-      if (ret == NETWIB_ERR_DATANOTAVAIL) continue;
+      if (ret == NETWIB_ERR_DATANOTAVAIL) {
+        ret = NETWIB_ERR_OK;
+        continue;
+      }
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
       break;
     }
