@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -888,7 +885,10 @@ netwib_err netwox_scan_loop(netwox_scan_method method,
       /* read */
       netwib__buf_reinit(&scan.pkt);
       ret = netwib_io_read(scan.pio, &scan.pkt);
-      if (ret == NETWIB_ERR_DATANOTAVAIL) continue;
+      if (ret == NETWIB_ERR_DATANOTAVAIL) {
+        ret = NETWIB_ERR_OK;
+        continue;
+      }
       netwib_er(ret);
       /* check it corresponds */
       netwib_er(netwox_scan_reply(&scan));
