@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -174,15 +171,8 @@ typedef enum {
 static netwib_err netwox_smbcmdtscq_encode_tsc_p(const netwox_smbcmd_transaction_q *ptsc,
                                                  netwox_smbcmdtscq *psmbcmdtscq)
 {
-  netwib_data para, data;
-  netwib_uint32 parasize, datasize;
   netwox_smbcmdtscq_p_subcmd subcmd;
 
-  para = netwib__buf_ref_data_ptr(&ptsc->para);
-  parasize = netwib__buf_ref_data_size(&ptsc->para);
-  data = netwib__buf_ref_data_ptr(&ptsc->data);
-  datasize = netwib__buf_ref_data_size(&ptsc->data);
-
   if (ptsc->setupcount == 0) {
     return(NETWIB_ERR_DATAMISSING);
   }
@@ -204,7 +194,7 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
                                                    netwox_smbcmdtscq *psmbcmdtscq)
 {
   netwib_buf descriptor;
-  netwib_data para, data;
+  netwib_data para;
   netwib_uint32 parasize, datasize;
   netwib_uint16 fmt;
   netwox_smbcmdtscq_plm_subcmd subcmd;
@@ -212,7 +202,6 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
 
   para = netwib__buf_ref_data_ptr(&ptsc->para);
   parasize = netwib__buf_ref_data_size(&ptsc->para);
-  data = netwib__buf_ref_data_ptr(&ptsc->data);
   datasize = netwib__buf_ref_data_size(&ptsc->data);
 
   if (parasize < 2) {
@@ -377,8 +366,6 @@ netwib_err netwox_smbcmdtscq_encode_smbcmd(netwox_constsmbcmd *psmbcmd,
 {
   netwib_buf buftocmp, bufstr;
   netwib_byte array[80];
-  netwib_data name;
-  netwib_uint32 namesize;
   netwib_cmp cmp;
 
   if (psmbcmd->type != NETWOX_SMBCMD_TYPE_TRANSACTION_Q) {
@@ -394,9 +381,6 @@ netwib_err netwox_smbcmdtscq_encode_smbcmd(netwox_constsmbcmd *psmbcmd,
     return(NETWIB_ERR_NOTCONVERTED);
   }
 
-  name = netwib__buf_ref_data_ptr(&psmbcmd->value.transaction_q.name);
-  namesize = netwib__buf_ref_data_size(&psmbcmd->value.transaction_q.name);
-
   if (psmbcmd->value.transaction_q.isunicode) {
     netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
     netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buftocmp));
