@@ -29,3 +29,8 @@ netwib_err netwox_timemsdos_init_time(netwib_consttime *ptime,
 netwib_err netwox_time_init_timemsdos(netwox_timemsdos timemsdos,
                                       netwib_time *ptime);
 netwib_err netwox_timemsdos_test(void);
+/* these functions set 0 on error */
+netwib_err netwox_time1601_init_timemsdos(netwox_timemsdos timemsdos,
+                                          netwox_time1601 *ptime1601);
+netwib_err netwox_timemsdos_init_time1601(netwox_time1601 time1601,
+                                          netwox_timemsdos *ptimemsdos);
