@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -501,12 +498,14 @@ static netwib_err t000171_loop_extendlease(t000171_infos *pinfos)
   netwib_er(netwib_time_plus_sec(&t, pinfos->extendleasetime));
   netwib_er(netwib_fmt_display("Press q to quit.\n"));
   while(NETWIB_TRUE) {
+    netwib__debug_ctrlc_pressed_break();
     netwib_er(netwib_wait_wait2(pwaitsniff, pwaitkbd, &t,
                                 &eventsniff, &eventkbd));
     if (eventkbd) {
       netwib__buf_reinit(pkbd);
       ret = netwib_io_read(piokbd, pkbd);
       if (ret == NETWIB_ERR_DATANOTAVAIL) {
+        ret = NETWIB_ERR_OK;
         continue;
       } else if (ret != NETWIB_ERR_OK) {
         break;
