@@ -1,24 +1,21 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2008 Laurent Constantin
+                Copyright(c) 1999-2012 Laurent CONSTANTIN
+                      http://ntwox.sourceforge.net/
+                        laurentconstantin@free.fr
                                   -----
 
-  Main server   : http://www.laurentconstantin.com/
-  Backup server : http://laurentconstantin.free.fr/
-  [my current email address is on the web servers]
-
-                                  -----
   This file is part of Netwox.
 
-  Netwox is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  version 2 as published by the Free Software Foundation.
+  Netwox is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License version 3
+  as published by the Free Software Foundation.
 
   Netwox is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details (http://www.gnu.org/).
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details (http://www.gnu.org/).
 
 ------------------------------------------------------------------------
 */
@@ -211,6 +208,7 @@ static netwib_err t000179_loop(t000179_infos *pinfos)
   netwib_er(netwib_time_init_now(&t));
   netwib_er(netwib_time_plus_msec(&t, pinfos->timeoutms));
   while(NETWIB_TRUE) {
+    netwib__debug_ctrlc_pressed_break();
     netwib_er(netwib_io_wait_read(pinfos->pio, &t, &event));
     if (!event) {
       return(NETWOX_ERR_TIMEOUT);
@@ -220,6 +218,7 @@ static netwib_err t000179_loop(t000179_infos *pinfos)
       break;
     } else if (ret == NETWIB_ERR_NOTCONVERTED ||
                ret == NETWIB_ERR_DATANOTAVAIL) {
+      ret = NETWIB_ERR_OK;
       continue;
     } else {
       return(ret);
