@@ -48,7 +48,7 @@
  #define NETWIBTESTDEF_FILE_NAME_2 "/etc/sdfsdf"
  #define NETWIBTESTDEF_FILE_EXISTS_2 NETWIB_FALSE
 #elif defined NETWIBDEF_SYSNAME_Windows
- #define NETWIBTESTDEF_FILE_NAME_1 "c:\\autoexec.bat"
+ #define NETWIBTESTDEF_FILE_NAME_1 "./netwibtest.exe"
  #define NETWIBTESTDEF_FILE_EXISTS_1 NETWIB_TRUE
  #define NETWIBTESTDEF_FILE_NAME_2 "c:\\sdfsdf"
  #define NETWIBTESTDEF_FILE_EXISTS_2 NETWIB_FALSE
