@@ -9,7 +9,7 @@ static netwib_err netwib_buf_encode_test2(netwib_conststring in,
   netwib_buf buf, bufin;
 
   netwib_er(netwib_buf_init_mallocdefault(&buf));
-  netwib_er(netwib_buf_init_ext_text(in, &bufin));
+  netwib_er(netwib_buf_init_ext_string(in, &bufin));
   netwib_er(netwib_buf_encode(&bufin, encodetype, &buf));
   netwib_er(netwib_buf_display(&buf, NETWIB_ENCODETYPE_DATA));
   netwib_er(netwibtest_buf_content3(&buf, wantedmixed));
@@ -217,14 +217,14 @@ static netwib_err netwib_buf_encode_transition_test3(netwib_encodetype et1,
   netwib_buf buf2;
   netwib_encodetype_context ctx;
 
-  netwib_er(netwib_buf_append_text("\n*******************************\n", pbuf));
+  netwib_er(netwib_buf_append_string("\n*******************************\n", pbuf));
   netwib_er(netwib_buf_append_encodetype(et1, pbuf));
-  netwib_er(netwib_buf_append_text(" -> ", pbuf));
+  netwib_er(netwib_buf_append_string(" -> ", pbuf));
   netwib_er(netwib_buf_append_encodetype(et2, pbuf));
-  netwib_er(netwib_buf_append_text(" :\n", pbuf));
+  netwib_er(netwib_buf_append_string(" :\n", pbuf));
 
   netwib_er(netwib_buf_init_mallocdefault(&buf2));
-  netwib_er(netwib_buf_append_text("abcd", &buf2));
+  netwib_er(netwib_buf_append_string("abcd", &buf2));
 
   netwib_er(netwib_buf_encode_transition_init(&ctx));
   netwib_er(netwib_buf_encode_transition(&ctx, et1, pbuf));
