@@ -4,9 +4,7 @@
 static netwib_err test__netwib_c2_uint(void)
 {
   char a;
-  int b;
   a = (char)(unsigned char)0xDA;
-  b = (int)0xDCBADCBA;
 
   puts("++++----\nTest of function netwib_c2_uint");
 
