@@ -102,7 +102,7 @@ static netwib_err netwib_ip_init_buf_test2(netwib_conststring ips,
   netwib_cmp cmp;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text(ips, &buf));
+  netwib_er(netwib_buf_init_ext_string(ips, &buf));
   ret = netwib_ip_init_buf_best(&buf, &ipa);
   if (ret != wantedret) {
     netwib_er(netwib_fmt_display("For %s :\n", ips));
@@ -130,7 +130,7 @@ netwib_err netwib_ip_init_buf_test3(netwib_conststring ips,
   netwib_buf buf;
   netwib_ip wantedip;
 
-  netwib_er(netwib_buf_init_ext_text(wantedips, &buf));
+  netwib_er(netwib_buf_init_ext_string(wantedips, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &wantedip));
   netwib_er(netwib_ip_init_buf_test2(ips, NETWIB_ERR_OK, &wantedip));
 
@@ -266,10 +266,10 @@ netwib_err netwib_ip_init_eth_test2(netwib_conststring eths,
   netwib_eth eth;
   netwib_cmp cmp;
 
-  netwib_er(netwib_buf_init_ext_text(wantedips, &buf));
+  netwib_er(netwib_buf_init_ext_string(wantedips, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &wantedip));
 
-  netwib_er(netwib_buf_init_ext_text(eths, &buf));
+  netwib_er(netwib_buf_init_ext_string(eths, &buf));
   netwib_er(netwib_eth_init_buf(&buf, &eth));
 
   netwib_er(netwib_ip_init_eth(&eth, &ipa));
@@ -364,7 +364,7 @@ static netwib_err netwib_ip_init_kbd_test(void)
   netwib_cmp cmp;
 
   puts("++++----\nTest of netwib_ip_init_kbd");
-  netwib_er(netwib_buf_init_ext_text("Enter \"sdf\" then \"1.2.3.4\"", &buf));
+  netwib_er(netwib_buf_init_ext_string("Enter \"sdf\" then \"1.2.3.4\"", &buf));
   netwib_er(netwib_ip_init_kbd(&buf, NETWIB_IP_INIT_KBD_NODEF, &ipa));
   netwib_er(netwib_ip_init_ip4(0x01020304, &wantedip));
   netwib_er(netwib_ip_cmp(&ipa, &wantedip, &cmp));
@@ -376,11 +376,11 @@ static netwib_err netwib_ip_init_kbd_test(void)
   if (NETWIBTESTDEF_HOST_NAMETOIP_1) {
     netwib_buf def;
     netwib_er(netwib_buf_init_mallocdefault(&buf));
-    netwib_er(netwib_buf_append_text("Press 'Return'", &buf));
-    netwib_er(netwib_buf_init_ext_text(NETWIBTESTDEF_HOST_NAME_1, &def));
+    netwib_er(netwib_buf_append_string("Press 'Return'", &buf));
+    netwib_er(netwib_buf_init_ext_string(NETWIBTESTDEF_HOST_NAME_1, &def));
     netwib_er(netwib_ip_init_kbd(&buf, &def, &ipa));
     netwib_er(netwib_buf_close(&buf));
-    netwib_er(netwib_buf_init_ext_text(NETWIBTESTDEF_HOST_IP_1, &buf));
+    netwib_er(netwib_buf_init_ext_string(NETWIBTESTDEF_HOST_IP_1, &buf));
     netwib_er(netwib_ip_init_buf_best(&buf, &wantedip));
     netwib_er(netwib_ip_cmp(ip, wantedip, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
@@ -446,7 +446,7 @@ netwib_err netwib_buf_append_ip_test3(netwib_conststring ips,
   netwib_buf buf;
   netwib_ip ipa;
 
-  netwib_er(netwib_buf_init_ext_text(ips, &buf));
+  netwib_er(netwib_buf_init_ext_string(ips, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &ipa));
 
   netwib_er(netwib_buf_append_ip_test2(&ipa, NETWIB_IP_ENCODETYPE_IP,
@@ -599,7 +599,7 @@ static netwib_err netwib_iptype_init_kbd_test(void)
   netwib_iptype type;
 
   puts("++++----\nTest of netwib_iptype_init_kbd");
-  netwib_er(netwib_buf_init_ext_text("Select...", &buf));
+  netwib_er(netwib_buf_init_ext_string("Select...", &buf));
   netwib_er(netwib_iptype_init_kbd(&buf, NETWIB_IPTYPE_IP6, &type));
   netwib_er(netwib_iptype_init_kbd(NULL, NETWIB_IPTYPE_INIT_KBD_NODEF, &type));
 
