@@ -9,9 +9,9 @@ static netwib_err test_1(netwib_conststring ips,
   netwib_buf buf;
   netwib_ip ipad, mask, net;
 
-  netwib_er(netwib_buf_init_ext_text(ips, &buf));
+  netwib_er(netwib_buf_init_ext_string(ips, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &ipad));
-  netwib_er(netwib_buf_init_ext_text(masks, &buf));
+  netwib_er(netwib_buf_init_ext_string(masks, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &mask));
   netwib_er(netwib_priv_ip_net_init_ipmaskprefix(&ipad, &mask, prefix, &net));
   netwib_er(netwibtest_ip_content(&net, wantnets));
@@ -37,9 +37,9 @@ static netwib_err test_2(netwib_conststring ips,
   netwib_ip ipad, net, mask;
   netwib_uint32 prefix;
 
-  netwib_er(netwib_buf_init_ext_text(ips, &buf));
+  netwib_er(netwib_buf_init_ext_string(ips, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &ipad));
-  netwib_er(netwib_buf_init_ext_text(nets, &buf));
+  netwib_er(netwib_buf_init_ext_string(nets, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &net));
 
   prefix = 0;
@@ -111,7 +111,7 @@ static netwib_err test_4(netwib_conststring str,
   netwib_ip net, mask;
   netwib_uint32 prefix;
 
-  netwib_er(netwib_buf_init_ext_text(str, &buf));
+  netwib_er(netwib_buf_init_ext_string(str, &buf));
   netwib_er(netwib_priv_ip_netmaskprefix_init_buf(&buf, &net, &mask,
                                                   &prefix));
   netwib_er(netwibtest_ip_content(&net, wantnets));
@@ -147,7 +147,7 @@ static netwib_err test_5(netwib_iptype iptype,
   netwib_ip net, mask;
   netwib_uint32 prefix;
 
-  netwib_er(netwib_buf_init_ext_text(str, &buf));
+  netwib_er(netwib_buf_init_ext_string(str, &buf));
   netwib_er(netwib_priv_ip_netmaskprefix_init_bufdefault(iptype, &buf, &net,
                                                          &mask, &prefix));
   netwib_er(netwibtest_ip_content(&net, wantnets));
@@ -192,7 +192,7 @@ static netwib_err test_6(netwib_conststring masks,
   netwib_ip mask;
   netwib_uint32 prefix;
 
-  netwib_er(netwib_buf_init_ext_text(masks, &buf));
+  netwib_er(netwib_buf_init_ext_string(masks, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &mask));
   netwib_er(netwib_priv_ip_prefix_init_mask(&mask, &prefix));
   if (prefix != wantprefix) {
