@@ -549,30 +549,30 @@ static netwib_err netwib_buf_append_localtime_test(void)
   netwib_er(netwib_time_decode_localtime(&t, &lt));
 
   netwib_er(netwib_buf_init_mallocdefault(&buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_NOTHING, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_NSEC_ZERO, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_NSEC_SPACE, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_SEC_ZERO, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_SEC_SPACE, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MIN_ZERO, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MIN_SPACE, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_HOUR_ZERO, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_HOUR_SPACE, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MDAY_ZERO, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MDAY_SPACE, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_ZERO, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_SPACE, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_SHORT, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_LONG, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YEAR_SHORT, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YEAR_LONG, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_WDAY_SHORT, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_WDAY_LONG, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YDAY_ZERO, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YDAY_SPACE, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_ZONE_SEC, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_ZONE_GMT, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
-  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_ZONE_HM, &buf)); netwib_er(netwib_buf_append_text("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_NOTHING, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_NSEC_ZERO, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_NSEC_SPACE, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_SEC_ZERO, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_SEC_SPACE, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MIN_ZERO, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MIN_SPACE, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_HOUR_ZERO, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_HOUR_SPACE, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MDAY_ZERO, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MDAY_SPACE, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_ZERO, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_SPACE, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_SHORT, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_MON_LONG, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YEAR_SHORT, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YEAR_LONG, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_WDAY_SHORT, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_WDAY_LONG, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YDAY_ZERO, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_YDAY_SPACE, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_ZONE_SEC, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_ZONE_GMT, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
+  netwib_er(netwib_buf_append_localtime(&lt, NETWIB_LOCALTIME_ENCODETYPE_ZONE_HM, &buf)); netwib_er(netwib_buf_append_string("\n", &buf));
 
   netwib_er(netwib_buf_display(&buf, NETWIB_ENCODETYPE_DATA));
   netwib_er(netwib_buf_close(&buf));
