@@ -187,7 +187,7 @@ netwib_err netwibtest_buf_content3(netwib_constbuf *pbuf,
 
   /* wanteddata */
   netwib_er(netwib_buf_init_mallocdefault(&wantedbuf));
-  netwib_er(netwib_buf_init_ext_text(wantedmixed, &wantedmixedbuf));
+  netwib_er(netwib_buf_init_ext_string(wantedmixed, &wantedmixedbuf));
   netwib_er(netwib_buf_decode(&wantedmixedbuf, NETWIB_DECODETYPE_MIXED,
                               &wantedbuf));
   wanteddata = netwib__buf_ref_data_ptr(&wantedbuf);
@@ -243,7 +243,7 @@ netwib_err netwibtest_ip_content(netwib_constip *pip,
   netwib_ip wantedip;
   netwib_cmp cmp;
 
-  netwib_er(netwib_buf_init_ext_text(wantedstring, &buf));
+  netwib_er(netwib_buf_init_ext_string(wantedstring, &buf));
   netwib_er(netwib_ip_init_buf_best(&buf, &wantedip));
 
   netwib_er(netwib_ip_cmp(&wantedip, pip, &cmp));
@@ -264,7 +264,7 @@ netwib_err netwibtest_eth_content(netwib_consteth *peth,
   netwib_eth wantedeth;
   netwib_cmp cmp;
 
-  netwib_er(netwib_buf_init_ext_text(wantedstring, &buf));
+  netwib_er(netwib_buf_init_ext_string(wantedstring, &buf));
   netwib_er(netwib_eth_init_buf(&buf, &wantedeth));
 
   netwib_er(netwib_eth_cmp(&wantedeth, peth, &cmp));
@@ -669,12 +669,12 @@ netwib_err netwibtest_ip6exts_init(netwib_ipproto lastproto,
   netwib_ip6ext ip6ext;
 
   ip6ext.proto = NETWIB_IPPROTO_HOPOPTS;
-  netwib_er(netwib_buf_init_ext_text("hello", &ip6ext.ext.hopopts.options));
+  netwib_er(netwib_buf_init_ext_string("hello", &ip6ext.ext.hopopts.options));
   ip6ext.nextproto = NETWIB_IPPROTO_DSTOPTS;
   netwib_er(netwib_pkt_append_ip6ext(&ip6ext, ppkt));
 
   ip6ext.proto = NETWIB_IPPROTO_DSTOPTS;
-  netwib_er(netwib_buf_init_ext_text("olleh", &ip6ext.ext.hopopts.options));
+  netwib_er(netwib_buf_init_ext_string("olleh", &ip6ext.ext.hopopts.options));
   ip6ext.nextproto = lastproto;
   netwib_er(netwib_pkt_append_ip6ext(&ip6ext, ppkt));
 
@@ -712,7 +712,7 @@ netwib_err netwibtest_uint64_init(netwib_conststring hexavalue,
   netwib_buf buf, bufhex;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text(hexavalue, &bufhex));
+  netwib_er(netwib_buf_init_ext_string(hexavalue, &bufhex));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   ret = netwib_buf_decode(&bufhex, NETWIB_DECODETYPE_HEXA, &buf);
   if (ret == NETWIB_ERR_OK) {
